/********************************************************************************
** Form generated from reading UI file 'x264ConfigDialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_X264CONFIGDIALOG_H
#define UI_X264CONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_x264ConfigDialog
{
public:
    QVBoxLayout *_11;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacer_8;
    QLabel *label_3;
    QComboBox *configurationComboBox;
    QPushButton *saveAsButton;
    QPushButton *deleteButton;
    QSpacerItem *spacer_9;
    QSpacerItem *spacer_7;
    QTabWidget *tabWidget;
    QWidget *tabGeneral;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *groupBoxBasic;
    QVBoxLayout *verticalLayout_11;
    QCheckBox *useAdvancedConfigurationCheckBox;
    QGridLayout *gridLayout_7;
    QLabel *label_46;
    QLabel *label_41;
    QHBoxLayout *horizontalLayout_11;
    QComboBox *presetComboBox;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *horizontalLayout_12;
    QComboBox *tuningComboBox;
    QSpacerItem *horizontalSpacer_9;
    QLabel *label_45;
    QLabel *label_53;
    QHBoxLayout *horizontalLayout_13;
    QComboBox *profileComboBox;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayout_14;
    QComboBox *idcLevelComboBox;
    QSpacerItem *horizontalSpacer_11;
    QCheckBox *fastDecodeCheckBox;
    QCheckBox *zeroLatencyCheckBox;
    QCheckBox *fastFirstPassCheckBox;
    QHBoxLayout *horizontalLayout_10;
    QLabel *labelThread;
    QComboBox *comboBoxThreads;
    QSpacerItem *horizontalSpacer_12;
    QGroupBox *groupBoxRateControl;
    QGridLayout *gridLayout_6;
    QGridLayout *gridLayout;
    QLabel *targetRateControlLabel1;
    QHBoxLayout *hboxLayout1;
    QComboBox *encodingModeComboBox;
    QSpacerItem *spacer_6;
    QLabel *label;
    QHBoxLayout *hboxLayout2;
    QSpinBox *targetRateControlSpinBox;
    QLabel *targetRateControlLabel2;
    QSpacerItem *spacer_5;
    QHBoxLayout *hboxLayout3;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *hboxLayout4;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout5;
    QLabel *quantiserLabel1;
    QSpacerItem *spacerItem;
    QLabel *quantiserLabel2;
    QSpacerItem *spacerItem1;
    QLabel *quantiserLabel3;
    QSlider *quantiserSlider;
    QSpinBox *quantiserSpinBox;
    QSpacerItem *spacer_4;
    QSpacerItem *spacerItem2;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabAdvancedRC;
    QVBoxLayout *verticalLayout_12;
    QGroupBox *groupBoxAdvRateControl;
    QVBoxLayout *verticalLayout_13;
    QCheckBox *maxCrfCheckBox;
    QHBoxLayout *_16;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *_17;
    QVBoxLayout *_18;
    QHBoxLayout *_19;
    QLabel *quantiserLabel1_2;
    QSpacerItem *spacerItem3;
    QLabel *quantiserLabel2_2;
    QSpacerItem *spacerItem4;
    QLabel *quantiserLabel3_2;
    QSlider *maxCrfSlider;
    QSpinBox *maxCrfSpinBox;
    QSpacerItem *spacer_22;
    QCheckBox *mbTreeCheckBox;
    QHBoxLayout *_36;
    QLabel *lblLookahead;
    QSpinBox *lookaheadSpinBox;
    QLabel *lblLookaheadFrames;
    QSpacerItem *spacer_3;
    QGridLayout *_20;
    QLabel *label_55;
    QHBoxLayout *_22;
    QComboBox *spsiComboBox;
    QSpacerItem *spacer_63;
    QSpacerItem *verticalSpacer_4;
    QWidget *tabMotion;
    QVBoxLayout *vboxLayout1;
    QGroupBox *groupBoxMotionEstimation;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout6;
    QLabel *label_38;
    QHBoxLayout *hboxLayout7;
    QComboBox *meMethodComboBox;
    QSpacerItem *spacer_10;
    QHBoxLayout *hboxLayout8;
    QHBoxLayout *hboxLayout9;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout10;
    QLabel *label_35;
    QSpacerItem *spacer_11;
    QLabel *label_36;
    QSpacerItem *spacer_13;
    QLabel *label_37;
    QSlider *meSlider;
    QSpinBox *meSpinBox;
    QSpacerItem *spacer_12;
    QGroupBox *groupBoxMV;
    QVBoxLayout *vboxLayout4;
    QGridLayout *gridLayout1;
    QHBoxLayout *hboxLayout11;
    QSpinBox *mvLengthSpinBox;
    QSpacerItem *spacer_14;
    QCheckBox *mvLengthCheckBox;
    QHBoxLayout *hboxLayout12;
    QSpinBox *minThreadBufferSpinBox;
    QSpacerItem *spacer_16;
    QHBoxLayout *hboxLayout13;
    QSpinBox *mvRangeSpinBox;
    QSpacerItem *spacer_15;
    QCheckBox *minThreadBufferCheckBox;
    QLabel *label_39;
    QGroupBox *groupBoxPred;
    QGridLayout *gridLayout2;
    QGridLayout *gridLayout3;
    QHBoxLayout *hboxLayout14;
    QComboBox *weightedPPredictComboBox;
    QSpacerItem *spacer_18;
    QLabel *label_40;
    QLabel *lblWeightedPPredict;
    QHBoxLayout *hboxLayout15;
    QComboBox *predictModeComboBox;
    QSpacerItem *spacer_17;
    QCheckBox *weightedPredictCheckBox;
    QCheckBox *constrainedIntraCheckBox;
    QSpacerItem *spacer_19;
    QWidget *tabPartition;
    QVBoxLayout *vboxLayout5;
    QGroupBox *groupBoxPart;
    QVBoxLayout *vboxLayout6;
    QVBoxLayout *vboxLayout7;
    QCheckBox *dct8x8CheckBox;
    QCheckBox *p8x8CheckBox;
    QCheckBox *b8x8CheckBox;
    QCheckBox *p4x4CheckBox;
    QCheckBox *i8x8CheckBox;
    QCheckBox *i4x4CheckBox;
    QSpacerItem *spacer_20;
    QWidget *tabFrame;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBoxFrameEnc;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *cabacCheckBox;
    QGridLayout *gridLayout_2;
    QCheckBox *loopFilterCheckBox;
    QHBoxLayout *hboxLayout16;
    QLabel *alphaC0Label;
    QSpinBox *alphaC0SpinBox;
    QSpacerItem *spacer_23;
    QLabel *betaLabel;
    QSpinBox *betaSpinBox;
    QSpacerItem *spacer_21;
    QCheckBox *openGopCheckBox;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *openGopComboBox;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *interlacedCheckBox;
    QHBoxLayout *horizontalLayout;
    QComboBox *interlacedComboBox;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *_3;
    QLabel *labelRefFrames;
    QHBoxLayout *hboxLayout17;
    QSpinBox *refFramesSpinBox;
    QSpacerItem *spacer_24;
    QGroupBox *groupBoxBframes;
    QGridLayout *gridLayout4;
    QLabel *label_33;
    QHBoxLayout *hboxLayout18;
    QComboBox *bFrameRefComboBox;
    QSpacerItem *spacer_28;
    QHBoxLayout *hboxLayout19;
    QComboBox *adaptiveBFrameComboBox;
    QSpacerItem *spacer_27;
    QHBoxLayout *hboxLayout20;
    QSpinBox *BFrameBiasSpinBox;
    QSpacerItem *spacer_26;
    QHBoxLayout *hboxLayout21;
    QSpinBox *maxBFramesSpinBox;
    QSpacerItem *spacer_25;
    QLabel *label_29;
    QLabel *label_31;
    QLabel *label_4;
    QGroupBox *groupBoxKeyFrames;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout_3;
    QLabel *label_34;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_28;
    QSpinBox *minGopSizeSpinBox;
    QSpacerItem *spacer_29;
    QLabel *label_26;
    QSpinBox *maxGopSizeSpinBox;
    QSpacerItem *spacer_30;
    QLabel *label_27;
    QHBoxLayout *hboxLayout22;
    QSpinBox *IFrameThresholdSpinBox;
    QSpacerItem *spacer_31;
    QCheckBox *intraRefreshCheckBox;
    QSpacerItem *spacer_32;
    QWidget *tabAnalysis;
    QVBoxLayout *vboxLayout8;
    QGroupBox *groupBoxAnalysis;
    QVBoxLayout *verticalLayout_10;
    QCheckBox *mixedRefsCheckBox;
    QCheckBox *chromaMotionEstCheckBox;
    QHBoxLayout *hboxLayout23;
    QCheckBox *trellisCheckBox;
    QComboBox *trellisComboBox;
    QSpacerItem *spacer_33;
    QCheckBox *fastPSkipCheckBox;
    QCheckBox *dctDecimateCheckBox;
    QHBoxLayout *horizontalLayout_5;
    QLabel *lblPsychoRDO;
    QDoubleSpinBox *psychoRdoSpinBox;
    QSpacerItem *spacer_34;
    QGridLayout *gridLayout_5;
    QLabel *lblPsyTrellis;
    QHBoxLayout *horizontalLayout_8;
    QDoubleSpinBox *psychoTrellisSpinBox;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_42;
    QHBoxLayout *horizontalLayout_9;
    QSpinBox *noiseReductionSpinBox;
    QSpacerItem *spacer_35;
    QGroupBox *groupBoxLumaQuant;
    QVBoxLayout *vboxLayout9;
    QGridLayout *gridLayout5;
    QLabel *label_44;
    QLabel *label_43;
    QHBoxLayout *hboxLayout24;
    QSpinBox *intraLumaSpinBox;
    QSpacerItem *spacer_36;
    QHBoxLayout *hboxLayout25;
    QSpinBox *interLumaSpinBox;
    QSpacerItem *spacer_37;
    QGroupBox *groupBoxQuantMatrix;
    QVBoxLayout *vboxLayout10;
    QVBoxLayout *vboxLayout11;
    QRadioButton *matrixFlatRadioButton;
    QRadioButton *matrixJvtRadioButton;
    QHBoxLayout *hboxLayout26;
    QRadioButton *matrixCustomRadioButton;
    QPushButton *matrixCustomEditButton;
    QSpacerItem *spacer_38;
    QSpacerItem *spacer_39;
    QWidget *tabQuantiser;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *groupBoxQuant;
    QVBoxLayout *vboxLayout12;
    QGridLayout *gridLayout6;
    QHBoxLayout *hboxLayout27;
    QSpinBox *quantiserMaxStepSpinBox;
    QSpacerItem *spacer_42;
    QLabel *label_16;
    QLabel *label_6;
    QHBoxLayout *hboxLayout28;
    QSpinBox *quantiserMinSpinBox;
    QSpacerItem *spacer_40;
    QHBoxLayout *hboxLayout29;
    QDoubleSpinBox *quantiserPbRatioSpinBox;
    QSpacerItem *spacer_44;
    QHBoxLayout *hboxLayout30;
    QSpinBox *avgBitrateToleranceSpinBox;
    QLabel *label_2;
    QSpacerItem *spacer_45;
    QLabel *label_17;
    QHBoxLayout *hboxLayout31;
    QSpinBox *chromaLumaOffsetSpinBox;
    QSpacerItem *spacer_41;
    QLabel *label_7;
    QLabel *label_5;
    QLabel *label_20;
    QHBoxLayout *hboxLayout32;
    QSpinBox *quantiserMaxSpinBox;
    QSpacerItem *spacer_46;
    QLabel *label_15;
    QHBoxLayout *hboxLayout33;
    QDoubleSpinBox *quantiserIpRatioSpinBox;
    QSpacerItem *spacer_43;
    QGroupBox *groupBoxQuantCurveCompress;
    QVBoxLayout *vboxLayout13;
    QHBoxLayout *hboxLayout34;
    QLabel *label_8;
    QHBoxLayout *hboxLayout35;
    QSpinBox *quantiserCurveCompressSpinBox;
    QLabel *label_18;
    QSpacerItem *spacer_49;
    QGridLayout *gridLayout7;
    QLabel *label_21;
    QHBoxLayout *hboxLayout36;
    QDoubleSpinBox *quantiserBeforeCompressSpinBox;
    QSpacerItem *spacer_50;
    QHBoxLayout *hboxLayout37;
    QDoubleSpinBox *quantiserAfterCompressSpinBox;
    QSpacerItem *spacer_48;
    QLabel *label_22;
    QGroupBox *aqGroupBox;
    QVBoxLayout *verticalLayout_8;
    QGridLayout *gridLayout_4;
    QCheckBox *aqVarianceCheckBox;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *aqAlgoComboBox;
    QSpacerItem *spacer_47;
    QLabel *aqStrengthLabel;
    QHBoxLayout *horizontalLayout_7;
    QDoubleSpinBox *aqStrengthSpinBox;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *spacer_52;
    QWidget *tabAdvanced1;
    QVBoxLayout *vboxLayout14;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout15;
    QGridLayout *gridLayout8;
    QLabel *label_9;
    QLabel *label_14;
    QHBoxLayout *hboxLayout38;
    QSpinBox *vbvBufferSizeSpinBox;
    QLabel *label_12;
    QSpacerItem *spacer_55;
    QHBoxLayout *hboxLayout39;
    QSpinBox *vbvBufferOccupancySpinBox;
    QLabel *label_13;
    QSpacerItem *spacer_58;
    QHBoxLayout *hboxLayout40;
    QSpinBox *vbvMaxBitrateSpinBox;
    QLabel *label_10;
    QSpacerItem *spacer_56;
    QLabel *label_11;
    QGroupBox *slicingGroupBox;
    QGridLayout *gridLayout9;
    QLabel *label_25;
    QLabel *label_23;
    QHBoxLayout *hboxLayout41;
    QSpinBox *maxSliceSizeSpinBox;
    QLabel *label_32;
    QSpacerItem *spacer_54;
    QLabel *label_24;
    QHBoxLayout *hboxLayout42;
    QSpinBox *maxSliceMbSpinBox;
    QSpacerItem *spacer_57;
    QHBoxLayout *hboxLayout43;
    QSpinBox *slicesPerFrameSpinBox;
    QSpacerItem *spacer_53;
    QGroupBox *groupBoxZones;
    QVBoxLayout *vboxLayout16;
    QHBoxLayout *_12;
    QTableView *zoneTableView;
    QVBoxLayout *_13;
    QPushButton *zoneAddButton;
    QPushButton *zoneEditButton;
    QPushButton *zoneDeleteButton;
    QSpacerItem *spacer_59;
    QWidget *tabAdvanced2;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBoxThreads;
    QVBoxLayout *_2;
    QVBoxLayout *_4;
    QRadioButton *threadDisableRadioButton;
    QRadioButton *threadAutoDetectRadioButton;
    QHBoxLayout *_14;
    QRadioButton *threadCustomRadioButton;
    QSpinBox *threadCustomSpinBox;
    QSpacerItem *spacer_2;
    QCheckBox *repeatabilityCheckBox;
    QCheckBox *sliceThreadingCheckBox;
    QHBoxLayout *_15;
    QCheckBox *threadedLookaheadCheckBox;
    QSpinBox *threadedLookaheadSpinBox;
    QLabel *lblThreadedFrames;
    QSpacerItem *spacer;
    QSpacerItem *verticalSpacer;
    QWidget *tabOutput1;
    QVBoxLayout *vboxLayout17;
    QGroupBox *groupBoxOutput;
    QVBoxLayout *vboxLayout18;
    QCheckBox *accessUnitCheckBox;
    QCheckBox *blueRayCompat;
    QCheckBox *fakeInterlaced;
    QGroupBox *groupBoxAspectRatio;
    QVBoxLayout *vboxLayout19;
    QGridLayout *gridLayout10;
    QRadioButton *sarCustomRadioButton;
    QRadioButton *sarAsInputRadioButton;
    QHBoxLayout *hboxLayout44;
    QLabel *sarAsInputLabel;
    QSpacerItem *spacer_65;
    QHBoxLayout *hboxLayout45;
    QSpinBox *sarCustomSpinBox1;
    QLabel *sarCustomLabel;
    QSpinBox *sarCustomSpinBox2;
    QSpacerItem *spacer_64;
    QRadioButton *sarPredefinedRadioButton;
    QHBoxLayout *hboxLayout46;
    QComboBox *sarPredefinedComboBox;
    QSpacerItem *spacer_62;
    QSpacerItem *spacer_60;
    QWidget *tabOutput2;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxVui;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_52;
    QSpacerItem *spacerItem5;
    QGridLayout *gridLayout11;
    QLabel *label_51;
    QHBoxLayout *_6;
    QComboBox *overscanComboBox;
    QSpacerItem *spacer_70;
    QLabel *label_50;
    QHBoxLayout *_8;
    QComboBox *videoFormatComboBox;
    QSpacerItem *spacer_68;
    QLabel *label_19;
    QHBoxLayout *_9;
    QComboBox *colourPrimariesComboBox;
    QSpacerItem *spacer_69;
    QLabel *label_48;
    QHBoxLayout *_5;
    QComboBox *transferCharacteristicsComboBox;
    QSpacerItem *spacer_67;
    QLabel *label_47;
    QHBoxLayout *_7;
    QComboBox *colourMatrixComboBox;
    QSpacerItem *spacer_71;
    QLabel *hrdLabel;
    QHBoxLayout *horizontalLayout_3;
    QComboBox *hrdComboBox;
    QSpacerItem *horizontalSpacer;
    QLabel *label_49;
    QHBoxLayout *_10;
    QSpinBox *chromaSampleSpinBox;
    QSpacerItem *spacer_66;
    QCheckBox *fullRangeSamplesCheckBox;
    QSpacerItem *spacer_72;
    QHBoxLayout *hboxLayout47;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *x264ConfigDialog)
    {
        if (x264ConfigDialog->objectName().isEmpty())
            x264ConfigDialog->setObjectName(QString::fromUtf8("x264ConfigDialog"));
        x264ConfigDialog->resize(567, 787);
        _11 = new QVBoxLayout(x264ConfigDialog);
        _11->setObjectName(QString::fromUtf8("_11"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        spacer_8 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacer_8);

        label_3 = new QLabel(x264ConfigDialog);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        hboxLayout->addWidget(label_3);

        configurationComboBox = new QComboBox(x264ConfigDialog);
        configurationComboBox->setObjectName(QString::fromUtf8("configurationComboBox"));
        configurationComboBox->setMinimumSize(QSize(200, 0));

        hboxLayout->addWidget(configurationComboBox);

        saveAsButton = new QPushButton(x264ConfigDialog);
        saveAsButton->setObjectName(QString::fromUtf8("saveAsButton"));

        hboxLayout->addWidget(saveAsButton);

        deleteButton = new QPushButton(x264ConfigDialog);
        deleteButton->setObjectName(QString::fromUtf8("deleteButton"));

        hboxLayout->addWidget(deleteButton);

        spacer_9 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacer_9);


        _11->addLayout(hboxLayout);

        spacer_7 = new QSpacerItem(0, 10, QSizePolicy::Minimum, QSizePolicy::Fixed);

        _11->addItem(spacer_7);

        tabWidget = new QTabWidget(x264ConfigDialog);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabGeneral = new QWidget();
        tabGeneral->setObjectName(QString::fromUtf8("tabGeneral"));
        verticalLayout_5 = new QVBoxLayout(tabGeneral);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        groupBoxBasic = new QGroupBox(tabGeneral);
        groupBoxBasic->setObjectName(QString::fromUtf8("groupBoxBasic"));
        verticalLayout_11 = new QVBoxLayout(groupBoxBasic);
        verticalLayout_11->setObjectName(QString::fromUtf8("verticalLayout_11"));
        useAdvancedConfigurationCheckBox = new QCheckBox(groupBoxBasic);
        useAdvancedConfigurationCheckBox->setObjectName(QString::fromUtf8("useAdvancedConfigurationCheckBox"));

        verticalLayout_11->addWidget(useAdvancedConfigurationCheckBox);

        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName(QString::fromUtf8("gridLayout_7"));
        label_46 = new QLabel(groupBoxBasic);
        label_46->setObjectName(QString::fromUtf8("label_46"));

        gridLayout_7->addWidget(label_46, 2, 0, 1, 1);

        label_41 = new QLabel(groupBoxBasic);
        label_41->setObjectName(QString::fromUtf8("label_41"));

        gridLayout_7->addWidget(label_41, 0, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName(QString::fromUtf8("horizontalLayout_11"));
        presetComboBox = new QComboBox(groupBoxBasic);
        presetComboBox->setObjectName(QString::fromUtf8("presetComboBox"));

        horizontalLayout_11->addWidget(presetComboBox);

        horizontalSpacer_8 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_8);


        gridLayout_7->addLayout(horizontalLayout_11, 0, 1, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName(QString::fromUtf8("horizontalLayout_12"));
        tuningComboBox = new QComboBox(groupBoxBasic);
        tuningComboBox->setObjectName(QString::fromUtf8("tuningComboBox"));

        horizontalLayout_12->addWidget(tuningComboBox);

        horizontalSpacer_9 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_9);


        gridLayout_7->addLayout(horizontalLayout_12, 1, 1, 1, 1);

        label_45 = new QLabel(groupBoxBasic);
        label_45->setObjectName(QString::fromUtf8("label_45"));

        gridLayout_7->addWidget(label_45, 1, 0, 1, 1);

        label_53 = new QLabel(groupBoxBasic);
        label_53->setObjectName(QString::fromUtf8("label_53"));

        gridLayout_7->addWidget(label_53, 3, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName(QString::fromUtf8("horizontalLayout_13"));
        profileComboBox = new QComboBox(groupBoxBasic);
        profileComboBox->setObjectName(QString::fromUtf8("profileComboBox"));

        horizontalLayout_13->addWidget(profileComboBox);

        horizontalSpacer_10 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_10);


        gridLayout_7->addLayout(horizontalLayout_13, 2, 1, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName(QString::fromUtf8("horizontalLayout_14"));
        idcLevelComboBox = new QComboBox(groupBoxBasic);
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->addItem(QString());
        idcLevelComboBox->setObjectName(QString::fromUtf8("idcLevelComboBox"));

        horizontalLayout_14->addWidget(idcLevelComboBox);

        horizontalSpacer_11 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_11);


        gridLayout_7->addLayout(horizontalLayout_14, 3, 1, 1, 1);


        verticalLayout_11->addLayout(gridLayout_7);

        fastDecodeCheckBox = new QCheckBox(groupBoxBasic);
        fastDecodeCheckBox->setObjectName(QString::fromUtf8("fastDecodeCheckBox"));

        verticalLayout_11->addWidget(fastDecodeCheckBox);

        zeroLatencyCheckBox = new QCheckBox(groupBoxBasic);
        zeroLatencyCheckBox->setObjectName(QString::fromUtf8("zeroLatencyCheckBox"));

        verticalLayout_11->addWidget(zeroLatencyCheckBox);

        fastFirstPassCheckBox = new QCheckBox(groupBoxBasic);
        fastFirstPassCheckBox->setObjectName(QString::fromUtf8("fastFirstPassCheckBox"));

        verticalLayout_11->addWidget(fastFirstPassCheckBox);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName(QString::fromUtf8("horizontalLayout_10"));
        labelThread = new QLabel(groupBoxBasic);
        labelThread->setObjectName(QString::fromUtf8("labelThread"));

        horizontalLayout_10->addWidget(labelThread);

        comboBoxThreads = new QComboBox(groupBoxBasic);
        comboBoxThreads->setObjectName(QString::fromUtf8("comboBoxThreads"));

        horizontalLayout_10->addWidget(comboBoxThreads);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_12);


        verticalLayout_11->addLayout(horizontalLayout_10);


        verticalLayout_5->addWidget(groupBoxBasic);

        groupBoxRateControl = new QGroupBox(tabGeneral);
        groupBoxRateControl->setObjectName(QString::fromUtf8("groupBoxRateControl"));
        gridLayout_6 = new QGridLayout(groupBoxRateControl);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        targetRateControlLabel1 = new QLabel(groupBoxRateControl);
        targetRateControlLabel1->setObjectName(QString::fromUtf8("targetRateControlLabel1"));

        gridLayout->addWidget(targetRateControlLabel1, 1, 0, 1, 1);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        encodingModeComboBox = new QComboBox(groupBoxRateControl);
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->addItem(QString());
        encodingModeComboBox->setObjectName(QString::fromUtf8("encodingModeComboBox"));

        hboxLayout1->addWidget(encodingModeComboBox);

        spacer_6 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacer_6);


        gridLayout->addLayout(hboxLayout1, 0, 1, 1, 1);

        label = new QLabel(groupBoxRateControl);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QString::fromUtf8("hboxLayout2"));
        targetRateControlSpinBox = new QSpinBox(groupBoxRateControl);
        targetRateControlSpinBox->setObjectName(QString::fromUtf8("targetRateControlSpinBox"));
        targetRateControlSpinBox->setMaximum(999999999);
        targetRateControlSpinBox->setValue(700);

        hboxLayout2->addWidget(targetRateControlSpinBox);

        targetRateControlLabel2 = new QLabel(groupBoxRateControl);
        targetRateControlLabel2->setObjectName(QString::fromUtf8("targetRateControlLabel2"));

        hboxLayout2->addWidget(targetRateControlLabel2);

        spacer_5 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout2->addItem(spacer_5);


        gridLayout->addLayout(hboxLayout2, 1, 1, 1, 1);


        gridLayout_6->addLayout(gridLayout, 0, 0, 1, 1);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setObjectName(QString::fromUtf8("hboxLayout3"));
        horizontalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout3->addItem(horizontalSpacer_3);

        hboxLayout4 = new QHBoxLayout();
        hboxLayout4->setSpacing(12);
        hboxLayout4->setObjectName(QString::fromUtf8("hboxLayout4"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setSpacing(0);
        hboxLayout5->setObjectName(QString::fromUtf8("hboxLayout5"));
        quantiserLabel1 = new QLabel(groupBoxRateControl);
        quantiserLabel1->setObjectName(QString::fromUtf8("quantiserLabel1"));
        quantiserLabel1->setEnabled(false);

        hboxLayout5->addWidget(quantiserLabel1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout5->addItem(spacerItem);

        quantiserLabel2 = new QLabel(groupBoxRateControl);
        quantiserLabel2->setObjectName(QString::fromUtf8("quantiserLabel2"));
        quantiserLabel2->setEnabled(false);

        hboxLayout5->addWidget(quantiserLabel2);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout5->addItem(spacerItem1);

        quantiserLabel3 = new QLabel(groupBoxRateControl);
        quantiserLabel3->setObjectName(QString::fromUtf8("quantiserLabel3"));
        quantiserLabel3->setEnabled(false);

        hboxLayout5->addWidget(quantiserLabel3);


        vboxLayout->addLayout(hboxLayout5);

        quantiserSlider = new QSlider(groupBoxRateControl);
        quantiserSlider->setObjectName(QString::fromUtf8("quantiserSlider"));
        quantiserSlider->setEnabled(false);
        quantiserSlider->setMinimumSize(QSize(375, 0));
        quantiserSlider->setMaximum(51);
        quantiserSlider->setPageStep(5);
        quantiserSlider->setValue(26);
        quantiserSlider->setOrientation(Qt::Horizontal);
        quantiserSlider->setTickPosition(QSlider::TicksBelow);

        vboxLayout->addWidget(quantiserSlider);


        hboxLayout4->addLayout(vboxLayout);

        quantiserSpinBox = new QSpinBox(groupBoxRateControl);
        quantiserSpinBox->setObjectName(QString::fromUtf8("quantiserSpinBox"));
        quantiserSpinBox->setEnabled(false);
        quantiserSpinBox->setMaximum(51);
        quantiserSpinBox->setValue(26);

        hboxLayout4->addWidget(quantiserSpinBox);


        hboxLayout3->addLayout(hboxLayout4);

        spacer_4 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout3->addItem(spacer_4);


        gridLayout_6->addLayout(hboxLayout3, 1, 0, 1, 1);

        spacerItem2 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_6->addItem(spacerItem2, 4, 0, 1, 1);


        verticalLayout_5->addWidget(groupBoxRateControl);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        tabWidget->addTab(tabGeneral, QString());
        tabAdvancedRC = new QWidget();
        tabAdvancedRC->setObjectName(QString::fromUtf8("tabAdvancedRC"));
        verticalLayout_12 = new QVBoxLayout(tabAdvancedRC);
        verticalLayout_12->setObjectName(QString::fromUtf8("verticalLayout_12"));
        groupBoxAdvRateControl = new QGroupBox(tabAdvancedRC);
        groupBoxAdvRateControl->setObjectName(QString::fromUtf8("groupBoxAdvRateControl"));
        verticalLayout_13 = new QVBoxLayout(groupBoxAdvRateControl);
        verticalLayout_13->setObjectName(QString::fromUtf8("verticalLayout_13"));
        maxCrfCheckBox = new QCheckBox(groupBoxAdvRateControl);
        maxCrfCheckBox->setObjectName(QString::fromUtf8("maxCrfCheckBox"));

        verticalLayout_13->addWidget(maxCrfCheckBox);

        _16 = new QHBoxLayout();
        _16->setObjectName(QString::fromUtf8("_16"));
        horizontalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        _16->addItem(horizontalSpacer_4);

        _17 = new QHBoxLayout();
        _17->setSpacing(12);
        _17->setObjectName(QString::fromUtf8("_17"));
        _18 = new QVBoxLayout();
        _18->setSpacing(0);
        _18->setObjectName(QString::fromUtf8("_18"));
        _19 = new QHBoxLayout();
        _19->setSpacing(0);
        _19->setObjectName(QString::fromUtf8("_19"));
        quantiserLabel1_2 = new QLabel(groupBoxAdvRateControl);
        quantiserLabel1_2->setObjectName(QString::fromUtf8("quantiserLabel1_2"));
        quantiserLabel1_2->setEnabled(false);

        _19->addWidget(quantiserLabel1_2);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _19->addItem(spacerItem3);

        quantiserLabel2_2 = new QLabel(groupBoxAdvRateControl);
        quantiserLabel2_2->setObjectName(QString::fromUtf8("quantiserLabel2_2"));
        quantiserLabel2_2->setEnabled(false);

        _19->addWidget(quantiserLabel2_2);

        spacerItem4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _19->addItem(spacerItem4);

        quantiserLabel3_2 = new QLabel(groupBoxAdvRateControl);
        quantiserLabel3_2->setObjectName(QString::fromUtf8("quantiserLabel3_2"));
        quantiserLabel3_2->setEnabled(false);

        _19->addWidget(quantiserLabel3_2);


        _18->addLayout(_19);

        maxCrfSlider = new QSlider(groupBoxAdvRateControl);
        maxCrfSlider->setObjectName(QString::fromUtf8("maxCrfSlider"));
        maxCrfSlider->setEnabled(false);
        maxCrfSlider->setMinimumSize(QSize(375, 0));
        maxCrfSlider->setMaximum(51);
        maxCrfSlider->setPageStep(5);
        maxCrfSlider->setValue(26);
        maxCrfSlider->setOrientation(Qt::Horizontal);
        maxCrfSlider->setTickPosition(QSlider::TicksBelow);

        _18->addWidget(maxCrfSlider);


        _17->addLayout(_18);

        maxCrfSpinBox = new QSpinBox(groupBoxAdvRateControl);
        maxCrfSpinBox->setObjectName(QString::fromUtf8("maxCrfSpinBox"));
        maxCrfSpinBox->setEnabled(false);
        maxCrfSpinBox->setMaximum(51);
        maxCrfSpinBox->setValue(26);

        _17->addWidget(maxCrfSpinBox);


        _16->addLayout(_17);

        spacer_22 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _16->addItem(spacer_22);


        verticalLayout_13->addLayout(_16);

        mbTreeCheckBox = new QCheckBox(groupBoxAdvRateControl);
        mbTreeCheckBox->setObjectName(QString::fromUtf8("mbTreeCheckBox"));

        verticalLayout_13->addWidget(mbTreeCheckBox);

        _36 = new QHBoxLayout();
        _36->setObjectName(QString::fromUtf8("_36"));
        lblLookahead = new QLabel(groupBoxAdvRateControl);
        lblLookahead->setObjectName(QString::fromUtf8("lblLookahead"));

        _36->addWidget(lblLookahead);

        lookaheadSpinBox = new QSpinBox(groupBoxAdvRateControl);
        lookaheadSpinBox->setObjectName(QString::fromUtf8("lookaheadSpinBox"));
        lookaheadSpinBox->setMaximum(250);

        _36->addWidget(lookaheadSpinBox);

        lblLookaheadFrames = new QLabel(groupBoxAdvRateControl);
        lblLookaheadFrames->setObjectName(QString::fromUtf8("lblLookaheadFrames"));

        _36->addWidget(lblLookaheadFrames);

        spacer_3 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _36->addItem(spacer_3);


        verticalLayout_13->addLayout(_36);

        _20 = new QGridLayout();
        _20->setObjectName(QString::fromUtf8("_20"));
        label_55 = new QLabel(groupBoxAdvRateControl);
        label_55->setObjectName(QString::fromUtf8("label_55"));

        _20->addWidget(label_55, 0, 0, 1, 1);

        _22 = new QHBoxLayout();
        _22->setObjectName(QString::fromUtf8("_22"));
        spsiComboBox = new QComboBox(groupBoxAdvRateControl);
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->addItem(QString());
        spsiComboBox->setObjectName(QString::fromUtf8("spsiComboBox"));

        _22->addWidget(spsiComboBox);

        spacer_63 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _22->addItem(spacer_63);


        _20->addLayout(_22, 0, 1, 1, 1);


        verticalLayout_13->addLayout(_20);


        verticalLayout_12->addWidget(groupBoxAdvRateControl);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_12->addItem(verticalSpacer_4);

        tabWidget->addTab(tabAdvancedRC, QString());
        tabMotion = new QWidget();
        tabMotion->setObjectName(QString::fromUtf8("tabMotion"));
        vboxLayout1 = new QVBoxLayout(tabMotion);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        groupBoxMotionEstimation = new QGroupBox(tabMotion);
        groupBoxMotionEstimation->setObjectName(QString::fromUtf8("groupBoxMotionEstimation"));
        vboxLayout2 = new QVBoxLayout(groupBoxMotionEstimation);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        hboxLayout6 = new QHBoxLayout();
        hboxLayout6->setObjectName(QString::fromUtf8("hboxLayout6"));
        label_38 = new QLabel(groupBoxMotionEstimation);
        label_38->setObjectName(QString::fromUtf8("label_38"));

        hboxLayout6->addWidget(label_38);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setObjectName(QString::fromUtf8("hboxLayout7"));
        meMethodComboBox = new QComboBox(groupBoxMotionEstimation);
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->addItem(QString());
        meMethodComboBox->setObjectName(QString::fromUtf8("meMethodComboBox"));

        hboxLayout7->addWidget(meMethodComboBox);

        spacer_10 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout7->addItem(spacer_10);


        hboxLayout6->addLayout(hboxLayout7);


        vboxLayout2->addLayout(hboxLayout6);

        hboxLayout8 = new QHBoxLayout();
        hboxLayout8->setObjectName(QString::fromUtf8("hboxLayout8"));
        hboxLayout9 = new QHBoxLayout();
        hboxLayout9->setSpacing(12);
        hboxLayout9->setObjectName(QString::fromUtf8("hboxLayout9"));
        vboxLayout3 = new QVBoxLayout();
        vboxLayout3->setSpacing(0);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        hboxLayout10 = new QHBoxLayout();
        hboxLayout10->setSpacing(0);
        hboxLayout10->setObjectName(QString::fromUtf8("hboxLayout10"));
        label_35 = new QLabel(groupBoxMotionEstimation);
        label_35->setObjectName(QString::fromUtf8("label_35"));

        hboxLayout10->addWidget(label_35);

        spacer_11 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout10->addItem(spacer_11);

        label_36 = new QLabel(groupBoxMotionEstimation);
        label_36->setObjectName(QString::fromUtf8("label_36"));

        hboxLayout10->addWidget(label_36);

        spacer_13 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout10->addItem(spacer_13);

        label_37 = new QLabel(groupBoxMotionEstimation);
        label_37->setObjectName(QString::fromUtf8("label_37"));

        hboxLayout10->addWidget(label_37);


        vboxLayout3->addLayout(hboxLayout10);

        meSlider = new QSlider(groupBoxMotionEstimation);
        meSlider->setObjectName(QString::fromUtf8("meSlider"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(meSlider->sizePolicy().hasHeightForWidth());
        meSlider->setSizePolicy(sizePolicy);
        meSlider->setMinimumSize(QSize(375, 0));
        meSlider->setMinimum(1);
        meSlider->setMaximum(11);
        meSlider->setPageStep(1);
        meSlider->setValue(7);
        meSlider->setOrientation(Qt::Horizontal);
        meSlider->setTickPosition(QSlider::TicksBelow);

        vboxLayout3->addWidget(meSlider);


        hboxLayout9->addLayout(vboxLayout3);

        meSpinBox = new QSpinBox(groupBoxMotionEstimation);
        meSpinBox->setObjectName(QString::fromUtf8("meSpinBox"));
        meSpinBox->setMinimum(1);
        meSpinBox->setMaximum(11);
        meSpinBox->setValue(7);

        hboxLayout9->addWidget(meSpinBox);


        hboxLayout8->addLayout(hboxLayout9);

        spacer_12 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout8->addItem(spacer_12);


        vboxLayout2->addLayout(hboxLayout8);


        vboxLayout1->addWidget(groupBoxMotionEstimation);

        groupBoxMV = new QGroupBox(tabMotion);
        groupBoxMV->setObjectName(QString::fromUtf8("groupBoxMV"));
        vboxLayout4 = new QVBoxLayout(groupBoxMV);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        hboxLayout11 = new QHBoxLayout();
        hboxLayout11->setObjectName(QString::fromUtf8("hboxLayout11"));
        mvLengthSpinBox = new QSpinBox(groupBoxMV);
        mvLengthSpinBox->setObjectName(QString::fromUtf8("mvLengthSpinBox"));
        mvLengthSpinBox->setEnabled(false);
        mvLengthSpinBox->setMinimum(32);
        mvLengthSpinBox->setMaximum(512);

        hboxLayout11->addWidget(mvLengthSpinBox);

        spacer_14 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout11->addItem(spacer_14);


        gridLayout1->addLayout(hboxLayout11, 1, 1, 1, 1);

        mvLengthCheckBox = new QCheckBox(groupBoxMV);
        mvLengthCheckBox->setObjectName(QString::fromUtf8("mvLengthCheckBox"));

        gridLayout1->addWidget(mvLengthCheckBox, 1, 0, 1, 1);

        hboxLayout12 = new QHBoxLayout();
        hboxLayout12->setObjectName(QString::fromUtf8("hboxLayout12"));
        minThreadBufferSpinBox = new QSpinBox(groupBoxMV);
        minThreadBufferSpinBox->setObjectName(QString::fromUtf8("minThreadBufferSpinBox"));
        minThreadBufferSpinBox->setEnabled(false);
        minThreadBufferSpinBox->setMinimum(0);
        minThreadBufferSpinBox->setMaximum(2147483647);
        minThreadBufferSpinBox->setSingleStep(1);
        minThreadBufferSpinBox->setValue(0);

        hboxLayout12->addWidget(minThreadBufferSpinBox);

        spacer_16 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout12->addItem(spacer_16);


        gridLayout1->addLayout(hboxLayout12, 2, 1, 1, 1);

        hboxLayout13 = new QHBoxLayout();
        hboxLayout13->setObjectName(QString::fromUtf8("hboxLayout13"));
        mvRangeSpinBox = new QSpinBox(groupBoxMV);
        mvRangeSpinBox->setObjectName(QString::fromUtf8("mvRangeSpinBox"));
        mvRangeSpinBox->setMaximum(64);
        mvRangeSpinBox->setValue(16);

        hboxLayout13->addWidget(mvRangeSpinBox);

        spacer_15 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout13->addItem(spacer_15);


        gridLayout1->addLayout(hboxLayout13, 0, 1, 1, 1);

        minThreadBufferCheckBox = new QCheckBox(groupBoxMV);
        minThreadBufferCheckBox->setObjectName(QString::fromUtf8("minThreadBufferCheckBox"));

        gridLayout1->addWidget(minThreadBufferCheckBox, 2, 0, 1, 1);

        label_39 = new QLabel(groupBoxMV);
        label_39->setObjectName(QString::fromUtf8("label_39"));

        gridLayout1->addWidget(label_39, 0, 0, 1, 1);


        vboxLayout4->addLayout(gridLayout1);


        vboxLayout1->addWidget(groupBoxMV);

        groupBoxPred = new QGroupBox(tabMotion);
        groupBoxPred->setObjectName(QString::fromUtf8("groupBoxPred"));
        gridLayout2 = new QGridLayout(groupBoxPred);
        gridLayout2->setObjectName(QString::fromUtf8("gridLayout2"));
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName(QString::fromUtf8("gridLayout3"));
        hboxLayout14 = new QHBoxLayout();
        hboxLayout14->setObjectName(QString::fromUtf8("hboxLayout14"));
        weightedPPredictComboBox = new QComboBox(groupBoxPred);
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->addItem(QString());
        weightedPPredictComboBox->setObjectName(QString::fromUtf8("weightedPPredictComboBox"));

        hboxLayout14->addWidget(weightedPPredictComboBox);

        spacer_18 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout14->addItem(spacer_18);


        gridLayout3->addLayout(hboxLayout14, 1, 1, 1, 1);

        label_40 = new QLabel(groupBoxPred);
        label_40->setObjectName(QString::fromUtf8("label_40"));

        gridLayout3->addWidget(label_40, 0, 0, 1, 1);

        lblWeightedPPredict = new QLabel(groupBoxPred);
        lblWeightedPPredict->setObjectName(QString::fromUtf8("lblWeightedPPredict"));

        gridLayout3->addWidget(lblWeightedPPredict, 1, 0, 1, 1);

        hboxLayout15 = new QHBoxLayout();
        hboxLayout15->setObjectName(QString::fromUtf8("hboxLayout15"));
        predictModeComboBox = new QComboBox(groupBoxPred);
        predictModeComboBox->addItem(QString());
        predictModeComboBox->addItem(QString());
        predictModeComboBox->addItem(QString());
        predictModeComboBox->addItem(QString());
        predictModeComboBox->setObjectName(QString::fromUtf8("predictModeComboBox"));

        hboxLayout15->addWidget(predictModeComboBox);

        spacer_17 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout15->addItem(spacer_17);


        gridLayout3->addLayout(hboxLayout15, 0, 1, 1, 1);


        gridLayout2->addLayout(gridLayout3, 0, 0, 1, 1);

        weightedPredictCheckBox = new QCheckBox(groupBoxPred);
        weightedPredictCheckBox->setObjectName(QString::fromUtf8("weightedPredictCheckBox"));

        gridLayout2->addWidget(weightedPredictCheckBox, 1, 0, 1, 1);

        constrainedIntraCheckBox = new QCheckBox(groupBoxPred);
        constrainedIntraCheckBox->setObjectName(QString::fromUtf8("constrainedIntraCheckBox"));

        gridLayout2->addWidget(constrainedIntraCheckBox, 2, 0, 1, 1);


        vboxLayout1->addWidget(groupBoxPred);

        spacer_19 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacer_19);

        tabWidget->addTab(tabMotion, QString());
        tabPartition = new QWidget();
        tabPartition->setObjectName(QString::fromUtf8("tabPartition"));
        vboxLayout5 = new QVBoxLayout(tabPartition);
        vboxLayout5->setObjectName(QString::fromUtf8("vboxLayout5"));
        groupBoxPart = new QGroupBox(tabPartition);
        groupBoxPart->setObjectName(QString::fromUtf8("groupBoxPart"));
        vboxLayout6 = new QVBoxLayout(groupBoxPart);
        vboxLayout6->setObjectName(QString::fromUtf8("vboxLayout6"));
        vboxLayout7 = new QVBoxLayout();
        vboxLayout7->setObjectName(QString::fromUtf8("vboxLayout7"));
        dct8x8CheckBox = new QCheckBox(groupBoxPart);
        dct8x8CheckBox->setObjectName(QString::fromUtf8("dct8x8CheckBox"));

        vboxLayout7->addWidget(dct8x8CheckBox);

        p8x8CheckBox = new QCheckBox(groupBoxPart);
        p8x8CheckBox->setObjectName(QString::fromUtf8("p8x8CheckBox"));

        vboxLayout7->addWidget(p8x8CheckBox);

        b8x8CheckBox = new QCheckBox(groupBoxPart);
        b8x8CheckBox->setObjectName(QString::fromUtf8("b8x8CheckBox"));

        vboxLayout7->addWidget(b8x8CheckBox);

        p4x4CheckBox = new QCheckBox(groupBoxPart);
        p4x4CheckBox->setObjectName(QString::fromUtf8("p4x4CheckBox"));

        vboxLayout7->addWidget(p4x4CheckBox);

        i8x8CheckBox = new QCheckBox(groupBoxPart);
        i8x8CheckBox->setObjectName(QString::fromUtf8("i8x8CheckBox"));

        vboxLayout7->addWidget(i8x8CheckBox);

        i4x4CheckBox = new QCheckBox(groupBoxPart);
        i4x4CheckBox->setObjectName(QString::fromUtf8("i4x4CheckBox"));

        vboxLayout7->addWidget(i4x4CheckBox);


        vboxLayout6->addLayout(vboxLayout7);


        vboxLayout5->addWidget(groupBoxPart);

        spacer_20 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout5->addItem(spacer_20);

        tabWidget->addTab(tabPartition, QString());
        tabFrame = new QWidget();
        tabFrame->setObjectName(QString::fromUtf8("tabFrame"));
        verticalLayout_7 = new QVBoxLayout(tabFrame);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        groupBoxFrameEnc = new QGroupBox(tabFrame);
        groupBoxFrameEnc->setObjectName(QString::fromUtf8("groupBoxFrameEnc"));
        verticalLayout_3 = new QVBoxLayout(groupBoxFrameEnc);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        cabacCheckBox = new QCheckBox(groupBoxFrameEnc);
        cabacCheckBox->setObjectName(QString::fromUtf8("cabacCheckBox"));

        verticalLayout_3->addWidget(cabacCheckBox);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        loopFilterCheckBox = new QCheckBox(groupBoxFrameEnc);
        loopFilterCheckBox->setObjectName(QString::fromUtf8("loopFilterCheckBox"));

        gridLayout_2->addWidget(loopFilterCheckBox, 0, 0, 1, 1);

        hboxLayout16 = new QHBoxLayout();
        hboxLayout16->setObjectName(QString::fromUtf8("hboxLayout16"));
        alphaC0Label = new QLabel(groupBoxFrameEnc);
        alphaC0Label->setObjectName(QString::fromUtf8("alphaC0Label"));
        alphaC0Label->setEnabled(false);

        hboxLayout16->addWidget(alphaC0Label);

        alphaC0SpinBox = new QSpinBox(groupBoxFrameEnc);
        alphaC0SpinBox->setObjectName(QString::fromUtf8("alphaC0SpinBox"));
        alphaC0SpinBox->setEnabled(false);
        alphaC0SpinBox->setMinimum(-6);
        alphaC0SpinBox->setMaximum(6);

        hboxLayout16->addWidget(alphaC0SpinBox);

        spacer_23 = new QSpacerItem(10, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout16->addItem(spacer_23);

        betaLabel = new QLabel(groupBoxFrameEnc);
        betaLabel->setObjectName(QString::fromUtf8("betaLabel"));
        betaLabel->setEnabled(false);

        hboxLayout16->addWidget(betaLabel);

        betaSpinBox = new QSpinBox(groupBoxFrameEnc);
        betaSpinBox->setObjectName(QString::fromUtf8("betaSpinBox"));
        betaSpinBox->setEnabled(false);
        betaSpinBox->setMinimum(-6);
        betaSpinBox->setMaximum(6);

        hboxLayout16->addWidget(betaSpinBox);

        spacer_21 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout16->addItem(spacer_21);


        gridLayout_2->addLayout(hboxLayout16, 0, 1, 1, 1);

        openGopCheckBox = new QCheckBox(groupBoxFrameEnc);
        openGopCheckBox->setObjectName(QString::fromUtf8("openGopCheckBox"));

        gridLayout_2->addWidget(openGopCheckBox, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        openGopComboBox = new QComboBox(groupBoxFrameEnc);
        openGopComboBox->addItem(QString());
        openGopComboBox->addItem(QString());
        openGopComboBox->setObjectName(QString::fromUtf8("openGopComboBox"));
        openGopComboBox->setEnabled(false);

        horizontalLayout_4->addWidget(openGopComboBox);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        gridLayout_2->addLayout(horizontalLayout_4, 1, 1, 1, 1);

        interlacedCheckBox = new QCheckBox(groupBoxFrameEnc);
        interlacedCheckBox->setObjectName(QString::fromUtf8("interlacedCheckBox"));

        gridLayout_2->addWidget(interlacedCheckBox, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        interlacedComboBox = new QComboBox(groupBoxFrameEnc);
        interlacedComboBox->addItem(QString());
        interlacedComboBox->addItem(QString());
        interlacedComboBox->setObjectName(QString::fromUtf8("interlacedComboBox"));
        interlacedComboBox->setEnabled(false);

        horizontalLayout->addWidget(interlacedComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout, 2, 1, 1, 1);


        verticalLayout_3->addLayout(gridLayout_2);

        _3 = new QHBoxLayout();
        _3->setObjectName(QString::fromUtf8("_3"));
        _3->setContentsMargins(0, -1, -1, -1);
        labelRefFrames = new QLabel(groupBoxFrameEnc);
        labelRefFrames->setObjectName(QString::fromUtf8("labelRefFrames"));

        _3->addWidget(labelRefFrames);

        hboxLayout17 = new QHBoxLayout();
        hboxLayout17->setObjectName(QString::fromUtf8("hboxLayout17"));
        refFramesSpinBox = new QSpinBox(groupBoxFrameEnc);
        refFramesSpinBox->setObjectName(QString::fromUtf8("refFramesSpinBox"));
        refFramesSpinBox->setMinimum(1);
        refFramesSpinBox->setMaximum(16);

        hboxLayout17->addWidget(refFramesSpinBox);

        spacer_24 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout17->addItem(spacer_24);


        _3->addLayout(hboxLayout17);


        verticalLayout_3->addLayout(_3);


        verticalLayout_7->addWidget(groupBoxFrameEnc);

        groupBoxBframes = new QGroupBox(tabFrame);
        groupBoxBframes->setObjectName(QString::fromUtf8("groupBoxBframes"));
        gridLayout4 = new QGridLayout(groupBoxBframes);
        gridLayout4->setObjectName(QString::fromUtf8("gridLayout4"));
        label_33 = new QLabel(groupBoxBframes);
        label_33->setObjectName(QString::fromUtf8("label_33"));

        gridLayout4->addWidget(label_33, 4, 0, 1, 1);

        hboxLayout18 = new QHBoxLayout();
        hboxLayout18->setObjectName(QString::fromUtf8("hboxLayout18"));
        bFrameRefComboBox = new QComboBox(groupBoxBframes);
        bFrameRefComboBox->addItem(QString());
        bFrameRefComboBox->addItem(QString());
        bFrameRefComboBox->addItem(QString());
        bFrameRefComboBox->setObjectName(QString::fromUtf8("bFrameRefComboBox"));

        hboxLayout18->addWidget(bFrameRefComboBox);

        spacer_28 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout18->addItem(spacer_28);


        gridLayout4->addLayout(hboxLayout18, 4, 1, 1, 1);

        hboxLayout19 = new QHBoxLayout();
        hboxLayout19->setObjectName(QString::fromUtf8("hboxLayout19"));
        adaptiveBFrameComboBox = new QComboBox(groupBoxBframes);
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->addItem(QString());
        adaptiveBFrameComboBox->setObjectName(QString::fromUtf8("adaptiveBFrameComboBox"));

        hboxLayout19->addWidget(adaptiveBFrameComboBox);

        spacer_27 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout19->addItem(spacer_27);


        gridLayout4->addLayout(hboxLayout19, 3, 1, 1, 1);

        hboxLayout20 = new QHBoxLayout();
        hboxLayout20->setObjectName(QString::fromUtf8("hboxLayout20"));
        BFrameBiasSpinBox = new QSpinBox(groupBoxBframes);
        BFrameBiasSpinBox->setObjectName(QString::fromUtf8("BFrameBiasSpinBox"));
        BFrameBiasSpinBox->setMinimum(-100);
        BFrameBiasSpinBox->setMaximum(100);

        hboxLayout20->addWidget(BFrameBiasSpinBox);

        spacer_26 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout20->addItem(spacer_26);


        gridLayout4->addLayout(hboxLayout20, 1, 1, 2, 1);

        hboxLayout21 = new QHBoxLayout();
        hboxLayout21->setObjectName(QString::fromUtf8("hboxLayout21"));
        maxBFramesSpinBox = new QSpinBox(groupBoxBframes);
        maxBFramesSpinBox->setObjectName(QString::fromUtf8("maxBFramesSpinBox"));
        maxBFramesSpinBox->setMaximum(16);

        hboxLayout21->addWidget(maxBFramesSpinBox);

        spacer_25 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout21->addItem(spacer_25);


        gridLayout4->addLayout(hboxLayout21, 0, 1, 1, 1);

        label_29 = new QLabel(groupBoxBframes);
        label_29->setObjectName(QString::fromUtf8("label_29"));

        gridLayout4->addWidget(label_29, 1, 0, 1, 1);

        label_31 = new QLabel(groupBoxBframes);
        label_31->setObjectName(QString::fromUtf8("label_31"));

        gridLayout4->addWidget(label_31, 0, 0, 1, 1);

        label_4 = new QLabel(groupBoxBframes);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout4->addWidget(label_4, 2, 0, 2, 1);


        verticalLayout_7->addWidget(groupBoxBframes);

        groupBoxKeyFrames = new QGroupBox(tabFrame);
        groupBoxKeyFrames->setObjectName(QString::fromUtf8("groupBoxKeyFrames"));
        verticalLayout_6 = new QVBoxLayout(groupBoxKeyFrames);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label_34 = new QLabel(groupBoxKeyFrames);
        label_34->setObjectName(QString::fromUtf8("label_34"));

        gridLayout_3->addWidget(label_34, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_28 = new QLabel(groupBoxKeyFrames);
        label_28->setObjectName(QString::fromUtf8("label_28"));

        horizontalLayout_2->addWidget(label_28);

        minGopSizeSpinBox = new QSpinBox(groupBoxKeyFrames);
        minGopSizeSpinBox->setObjectName(QString::fromUtf8("minGopSizeSpinBox"));
        minGopSizeSpinBox->setMaximum(100);
        minGopSizeSpinBox->setValue(25);

        horizontalLayout_2->addWidget(minGopSizeSpinBox);

        spacer_29 = new QSpacerItem(10, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacer_29);

        label_26 = new QLabel(groupBoxKeyFrames);
        label_26->setObjectName(QString::fromUtf8("label_26"));

        horizontalLayout_2->addWidget(label_26);

        maxGopSizeSpinBox = new QSpinBox(groupBoxKeyFrames);
        maxGopSizeSpinBox->setObjectName(QString::fromUtf8("maxGopSizeSpinBox"));
        maxGopSizeSpinBox->setMaximum(1000);
        maxGopSizeSpinBox->setValue(250);

        horizontalLayout_2->addWidget(maxGopSizeSpinBox);

        spacer_30 = new QSpacerItem(168, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacer_30);


        gridLayout_3->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        label_27 = new QLabel(groupBoxKeyFrames);
        label_27->setObjectName(QString::fromUtf8("label_27"));

        gridLayout_3->addWidget(label_27, 1, 0, 1, 1);

        hboxLayout22 = new QHBoxLayout();
        hboxLayout22->setObjectName(QString::fromUtf8("hboxLayout22"));
        IFrameThresholdSpinBox = new QSpinBox(groupBoxKeyFrames);
        IFrameThresholdSpinBox->setObjectName(QString::fromUtf8("IFrameThresholdSpinBox"));
        IFrameThresholdSpinBox->setMaximum(100);
        IFrameThresholdSpinBox->setValue(40);

        hboxLayout22->addWidget(IFrameThresholdSpinBox);

        spacer_31 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout22->addItem(spacer_31);


        gridLayout_3->addLayout(hboxLayout22, 1, 1, 1, 1);


        verticalLayout_6->addLayout(gridLayout_3);

        intraRefreshCheckBox = new QCheckBox(groupBoxKeyFrames);
        intraRefreshCheckBox->setObjectName(QString::fromUtf8("intraRefreshCheckBox"));

        verticalLayout_6->addWidget(intraRefreshCheckBox);


        verticalLayout_7->addWidget(groupBoxKeyFrames);

        spacer_32 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_7->addItem(spacer_32);

        tabWidget->addTab(tabFrame, QString());
        tabAnalysis = new QWidget();
        tabAnalysis->setObjectName(QString::fromUtf8("tabAnalysis"));
        vboxLayout8 = new QVBoxLayout(tabAnalysis);
        vboxLayout8->setObjectName(QString::fromUtf8("vboxLayout8"));
        groupBoxAnalysis = new QGroupBox(tabAnalysis);
        groupBoxAnalysis->setObjectName(QString::fromUtf8("groupBoxAnalysis"));
        verticalLayout_10 = new QVBoxLayout(groupBoxAnalysis);
        verticalLayout_10->setObjectName(QString::fromUtf8("verticalLayout_10"));
        mixedRefsCheckBox = new QCheckBox(groupBoxAnalysis);
        mixedRefsCheckBox->setObjectName(QString::fromUtf8("mixedRefsCheckBox"));

        verticalLayout_10->addWidget(mixedRefsCheckBox);

        chromaMotionEstCheckBox = new QCheckBox(groupBoxAnalysis);
        chromaMotionEstCheckBox->setObjectName(QString::fromUtf8("chromaMotionEstCheckBox"));

        verticalLayout_10->addWidget(chromaMotionEstCheckBox);

        hboxLayout23 = new QHBoxLayout();
        hboxLayout23->setObjectName(QString::fromUtf8("hboxLayout23"));
        trellisCheckBox = new QCheckBox(groupBoxAnalysis);
        trellisCheckBox->setObjectName(QString::fromUtf8("trellisCheckBox"));

        hboxLayout23->addWidget(trellisCheckBox);

        trellisComboBox = new QComboBox(groupBoxAnalysis);
        trellisComboBox->addItem(QString());
        trellisComboBox->addItem(QString());
        trellisComboBox->setObjectName(QString::fromUtf8("trellisComboBox"));
        trellisComboBox->setEnabled(false);

        hboxLayout23->addWidget(trellisComboBox);

        spacer_33 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout23->addItem(spacer_33);


        verticalLayout_10->addLayout(hboxLayout23);

        fastPSkipCheckBox = new QCheckBox(groupBoxAnalysis);
        fastPSkipCheckBox->setObjectName(QString::fromUtf8("fastPSkipCheckBox"));

        verticalLayout_10->addWidget(fastPSkipCheckBox);

        dctDecimateCheckBox = new QCheckBox(groupBoxAnalysis);
        dctDecimateCheckBox->setObjectName(QString::fromUtf8("dctDecimateCheckBox"));

        verticalLayout_10->addWidget(dctDecimateCheckBox);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        lblPsychoRDO = new QLabel(groupBoxAnalysis);
        lblPsychoRDO->setObjectName(QString::fromUtf8("lblPsychoRDO"));

        horizontalLayout_5->addWidget(lblPsychoRDO);

        psychoRdoSpinBox = new QDoubleSpinBox(groupBoxAnalysis);
        psychoRdoSpinBox->setObjectName(QString::fromUtf8("psychoRdoSpinBox"));
        psychoRdoSpinBox->setMaximum(10.000000000000000);
        psychoRdoSpinBox->setSingleStep(0.100000000000000);

        horizontalLayout_5->addWidget(psychoRdoSpinBox);

        spacer_34 = new QSpacerItem(13, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(spacer_34);


        verticalLayout_10->addLayout(horizontalLayout_5);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        lblPsyTrellis = new QLabel(groupBoxAnalysis);
        lblPsyTrellis->setObjectName(QString::fromUtf8("lblPsyTrellis"));
        lblPsyTrellis->setEnabled(false);

        gridLayout_5->addWidget(lblPsyTrellis, 0, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        psychoTrellisSpinBox = new QDoubleSpinBox(groupBoxAnalysis);
        psychoTrellisSpinBox->setObjectName(QString::fromUtf8("psychoTrellisSpinBox"));
        psychoTrellisSpinBox->setEnabled(false);
        psychoTrellisSpinBox->setMaximum(20.000000000000000);
        psychoTrellisSpinBox->setSingleStep(0.100000000000000);

        horizontalLayout_8->addWidget(psychoTrellisSpinBox);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_6);


        gridLayout_5->addLayout(horizontalLayout_8, 0, 1, 1, 1);

        label_42 = new QLabel(groupBoxAnalysis);
        label_42->setObjectName(QString::fromUtf8("label_42"));

        gridLayout_5->addWidget(label_42, 1, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName(QString::fromUtf8("horizontalLayout_9"));
        noiseReductionSpinBox = new QSpinBox(groupBoxAnalysis);
        noiseReductionSpinBox->setObjectName(QString::fromUtf8("noiseReductionSpinBox"));
        noiseReductionSpinBox->setMaximum(65536);

        horizontalLayout_9->addWidget(noiseReductionSpinBox);

        spacer_35 = new QSpacerItem(13, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_9->addItem(spacer_35);


        gridLayout_5->addLayout(horizontalLayout_9, 1, 1, 1, 1);


        verticalLayout_10->addLayout(gridLayout_5);


        vboxLayout8->addWidget(groupBoxAnalysis);

        groupBoxLumaQuant = new QGroupBox(tabAnalysis);
        groupBoxLumaQuant->setObjectName(QString::fromUtf8("groupBoxLumaQuant"));
        vboxLayout9 = new QVBoxLayout(groupBoxLumaQuant);
        vboxLayout9->setObjectName(QString::fromUtf8("vboxLayout9"));
        gridLayout5 = new QGridLayout();
        gridLayout5->setObjectName(QString::fromUtf8("gridLayout5"));
        label_44 = new QLabel(groupBoxLumaQuant);
        label_44->setObjectName(QString::fromUtf8("label_44"));

        gridLayout5->addWidget(label_44, 0, 0, 1, 1);

        label_43 = new QLabel(groupBoxLumaQuant);
        label_43->setObjectName(QString::fromUtf8("label_43"));

        gridLayout5->addWidget(label_43, 1, 0, 1, 1);

        hboxLayout24 = new QHBoxLayout();
        hboxLayout24->setObjectName(QString::fromUtf8("hboxLayout24"));
        intraLumaSpinBox = new QSpinBox(groupBoxLumaQuant);
        intraLumaSpinBox->setObjectName(QString::fromUtf8("intraLumaSpinBox"));
        intraLumaSpinBox->setMaximum(32);
        intraLumaSpinBox->setValue(21);

        hboxLayout24->addWidget(intraLumaSpinBox);

        spacer_36 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout24->addItem(spacer_36);


        gridLayout5->addLayout(hboxLayout24, 0, 1, 1, 1);

        hboxLayout25 = new QHBoxLayout();
        hboxLayout25->setObjectName(QString::fromUtf8("hboxLayout25"));
        interLumaSpinBox = new QSpinBox(groupBoxLumaQuant);
        interLumaSpinBox->setObjectName(QString::fromUtf8("interLumaSpinBox"));
        interLumaSpinBox->setMaximum(32);
        interLumaSpinBox->setValue(21);

        hboxLayout25->addWidget(interLumaSpinBox);

        spacer_37 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout25->addItem(spacer_37);


        gridLayout5->addLayout(hboxLayout25, 1, 1, 1, 1);


        vboxLayout9->addLayout(gridLayout5);


        vboxLayout8->addWidget(groupBoxLumaQuant);

        groupBoxQuantMatrix = new QGroupBox(tabAnalysis);
        groupBoxQuantMatrix->setObjectName(QString::fromUtf8("groupBoxQuantMatrix"));
        vboxLayout10 = new QVBoxLayout(groupBoxQuantMatrix);
        vboxLayout10->setObjectName(QString::fromUtf8("vboxLayout10"));
        vboxLayout11 = new QVBoxLayout();
        vboxLayout11->setObjectName(QString::fromUtf8("vboxLayout11"));
        matrixFlatRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixFlatRadioButton->setObjectName(QString::fromUtf8("matrixFlatRadioButton"));
        matrixFlatRadioButton->setChecked(true);

        vboxLayout11->addWidget(matrixFlatRadioButton);

        matrixJvtRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixJvtRadioButton->setObjectName(QString::fromUtf8("matrixJvtRadioButton"));

        vboxLayout11->addWidget(matrixJvtRadioButton);

        hboxLayout26 = new QHBoxLayout();
        hboxLayout26->setObjectName(QString::fromUtf8("hboxLayout26"));
        matrixCustomRadioButton = new QRadioButton(groupBoxQuantMatrix);
        matrixCustomRadioButton->setObjectName(QString::fromUtf8("matrixCustomRadioButton"));

        hboxLayout26->addWidget(matrixCustomRadioButton);

        matrixCustomEditButton = new QPushButton(groupBoxQuantMatrix);
        matrixCustomEditButton->setObjectName(QString::fromUtf8("matrixCustomEditButton"));
        matrixCustomEditButton->setEnabled(false);

        hboxLayout26->addWidget(matrixCustomEditButton);

        spacer_38 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout26->addItem(spacer_38);


        vboxLayout11->addLayout(hboxLayout26);


        vboxLayout10->addLayout(vboxLayout11);


        vboxLayout8->addWidget(groupBoxQuantMatrix);

        spacer_39 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout8->addItem(spacer_39);

        tabWidget->addTab(tabAnalysis, QString());
        tabQuantiser = new QWidget();
        tabQuantiser->setObjectName(QString::fromUtf8("tabQuantiser"));
        verticalLayout_9 = new QVBoxLayout(tabQuantiser);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        groupBoxQuant = new QGroupBox(tabQuantiser);
        groupBoxQuant->setObjectName(QString::fromUtf8("groupBoxQuant"));
        vboxLayout12 = new QVBoxLayout(groupBoxQuant);
        vboxLayout12->setObjectName(QString::fromUtf8("vboxLayout12"));
        gridLayout6 = new QGridLayout();
        gridLayout6->setObjectName(QString::fromUtf8("gridLayout6"));
        hboxLayout27 = new QHBoxLayout();
        hboxLayout27->setObjectName(QString::fromUtf8("hboxLayout27"));
        quantiserMaxStepSpinBox = new QSpinBox(groupBoxQuant);
        quantiserMaxStepSpinBox->setObjectName(QString::fromUtf8("quantiserMaxStepSpinBox"));
        quantiserMaxStepSpinBox->setMaximum(10);
        quantiserMaxStepSpinBox->setValue(4);

        hboxLayout27->addWidget(quantiserMaxStepSpinBox);

        spacer_42 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout27->addItem(spacer_42);


        gridLayout6->addLayout(hboxLayout27, 2, 1, 1, 1);

        label_16 = new QLabel(groupBoxQuant);
        label_16->setObjectName(QString::fromUtf8("label_16"));

        gridLayout6->addWidget(label_16, 1, 0, 1, 1);

        label_6 = new QLabel(groupBoxQuant);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout6->addWidget(label_6, 4, 0, 1, 1);

        hboxLayout28 = new QHBoxLayout();
        hboxLayout28->setObjectName(QString::fromUtf8("hboxLayout28"));
        quantiserMinSpinBox = new QSpinBox(groupBoxQuant);
        quantiserMinSpinBox->setObjectName(QString::fromUtf8("quantiserMinSpinBox"));
        quantiserMinSpinBox->setMaximum(69);
        quantiserMinSpinBox->setValue(0);

        hboxLayout28->addWidget(quantiserMinSpinBox);

        spacer_40 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout28->addItem(spacer_40);


        gridLayout6->addLayout(hboxLayout28, 0, 1, 1, 1);

        hboxLayout29 = new QHBoxLayout();
        hboxLayout29->setObjectName(QString::fromUtf8("hboxLayout29"));
        quantiserPbRatioSpinBox = new QDoubleSpinBox(groupBoxQuant);
        quantiserPbRatioSpinBox->setObjectName(QString::fromUtf8("quantiserPbRatioSpinBox"));
        quantiserPbRatioSpinBox->setDecimals(1);
        quantiserPbRatioSpinBox->setMinimum(1.000000000000000);
        quantiserPbRatioSpinBox->setMaximum(10.000000000000000);
        quantiserPbRatioSpinBox->setSingleStep(0.100000000000000);
        quantiserPbRatioSpinBox->setValue(1.300000000000000);

        hboxLayout29->addWidget(quantiserPbRatioSpinBox);

        spacer_44 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout29->addItem(spacer_44);


        gridLayout6->addLayout(hboxLayout29, 5, 1, 1, 1);

        hboxLayout30 = new QHBoxLayout();
        hboxLayout30->setObjectName(QString::fromUtf8("hboxLayout30"));
        avgBitrateToleranceSpinBox = new QSpinBox(groupBoxQuant);
        avgBitrateToleranceSpinBox->setObjectName(QString::fromUtf8("avgBitrateToleranceSpinBox"));
        avgBitrateToleranceSpinBox->setMinimum(0);
        avgBitrateToleranceSpinBox->setMaximum(100);
        avgBitrateToleranceSpinBox->setValue(100);

        hboxLayout30->addWidget(avgBitrateToleranceSpinBox);

        label_2 = new QLabel(groupBoxQuant);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        hboxLayout30->addWidget(label_2);

        spacer_45 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout30->addItem(spacer_45);


        gridLayout6->addLayout(hboxLayout30, 3, 1, 1, 1);

        label_17 = new QLabel(groupBoxQuant);
        label_17->setObjectName(QString::fromUtf8("label_17"));

        gridLayout6->addWidget(label_17, 2, 0, 1, 1);

        hboxLayout31 = new QHBoxLayout();
        hboxLayout31->setObjectName(QString::fromUtf8("hboxLayout31"));
        chromaLumaOffsetSpinBox = new QSpinBox(groupBoxQuant);
        chromaLumaOffsetSpinBox->setObjectName(QString::fromUtf8("chromaLumaOffsetSpinBox"));
        chromaLumaOffsetSpinBox->setMinimum(-12);
        chromaLumaOffsetSpinBox->setMaximum(12);

        hboxLayout31->addWidget(chromaLumaOffsetSpinBox);

        spacer_41 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout31->addItem(spacer_41);


        gridLayout6->addLayout(hboxLayout31, 6, 1, 1, 1);

        label_7 = new QLabel(groupBoxQuant);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout6->addWidget(label_7, 5, 0, 1, 1);

        label_5 = new QLabel(groupBoxQuant);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout6->addWidget(label_5, 3, 0, 1, 1);

        label_20 = new QLabel(groupBoxQuant);
        label_20->setObjectName(QString::fromUtf8("label_20"));

        gridLayout6->addWidget(label_20, 6, 0, 1, 1);

        hboxLayout32 = new QHBoxLayout();
        hboxLayout32->setObjectName(QString::fromUtf8("hboxLayout32"));
        quantiserMaxSpinBox = new QSpinBox(groupBoxQuant);
        quantiserMaxSpinBox->setObjectName(QString::fromUtf8("quantiserMaxSpinBox"));
        quantiserMaxSpinBox->setMaximum(69);
        quantiserMaxSpinBox->setValue(69);

        hboxLayout32->addWidget(quantiserMaxSpinBox);

        spacer_46 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout32->addItem(spacer_46);


        gridLayout6->addLayout(hboxLayout32, 1, 1, 1, 1);

        label_15 = new QLabel(groupBoxQuant);
        label_15->setObjectName(QString::fromUtf8("label_15"));

        gridLayout6->addWidget(label_15, 0, 0, 1, 1);

        hboxLayout33 = new QHBoxLayout();
        hboxLayout33->setObjectName(QString::fromUtf8("hboxLayout33"));
        quantiserIpRatioSpinBox = new QDoubleSpinBox(groupBoxQuant);
        quantiserIpRatioSpinBox->setObjectName(QString::fromUtf8("quantiserIpRatioSpinBox"));
        quantiserIpRatioSpinBox->setDecimals(1);
        quantiserIpRatioSpinBox->setMinimum(1.000000000000000);
        quantiserIpRatioSpinBox->setMaximum(10.000000000000000);
        quantiserIpRatioSpinBox->setSingleStep(0.100000000000000);
        quantiserIpRatioSpinBox->setValue(1.400000000000000);

        hboxLayout33->addWidget(quantiserIpRatioSpinBox);

        spacer_43 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout33->addItem(spacer_43);


        gridLayout6->addLayout(hboxLayout33, 4, 1, 1, 1);


        vboxLayout12->addLayout(gridLayout6);


        verticalLayout_9->addWidget(groupBoxQuant);

        groupBoxQuantCurveCompress = new QGroupBox(tabQuantiser);
        groupBoxQuantCurveCompress->setObjectName(QString::fromUtf8("groupBoxQuantCurveCompress"));
        vboxLayout13 = new QVBoxLayout(groupBoxQuantCurveCompress);
        vboxLayout13->setObjectName(QString::fromUtf8("vboxLayout13"));
        hboxLayout34 = new QHBoxLayout();
        hboxLayout34->setObjectName(QString::fromUtf8("hboxLayout34"));
        label_8 = new QLabel(groupBoxQuantCurveCompress);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        hboxLayout34->addWidget(label_8);

        hboxLayout35 = new QHBoxLayout();
        hboxLayout35->setObjectName(QString::fromUtf8("hboxLayout35"));
        quantiserCurveCompressSpinBox = new QSpinBox(groupBoxQuantCurveCompress);
        quantiserCurveCompressSpinBox->setObjectName(QString::fromUtf8("quantiserCurveCompressSpinBox"));
        quantiserCurveCompressSpinBox->setMaximum(100);
        quantiserCurveCompressSpinBox->setValue(60);

        hboxLayout35->addWidget(quantiserCurveCompressSpinBox);

        label_18 = new QLabel(groupBoxQuantCurveCompress);
        label_18->setObjectName(QString::fromUtf8("label_18"));

        hboxLayout35->addWidget(label_18);

        spacer_49 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout35->addItem(spacer_49);


        hboxLayout34->addLayout(hboxLayout35);


        vboxLayout13->addLayout(hboxLayout34);

        gridLayout7 = new QGridLayout();
        gridLayout7->setObjectName(QString::fromUtf8("gridLayout7"));
        label_21 = new QLabel(groupBoxQuantCurveCompress);
        label_21->setObjectName(QString::fromUtf8("label_21"));

        gridLayout7->addWidget(label_21, 0, 0, 1, 1);

        hboxLayout36 = new QHBoxLayout();
        hboxLayout36->setObjectName(QString::fromUtf8("hboxLayout36"));
        quantiserBeforeCompressSpinBox = new QDoubleSpinBox(groupBoxQuantCurveCompress);
        quantiserBeforeCompressSpinBox->setObjectName(QString::fromUtf8("quantiserBeforeCompressSpinBox"));
        quantiserBeforeCompressSpinBox->setDecimals(1);
        quantiserBeforeCompressSpinBox->setMaximum(999.000000000000000);
        quantiserBeforeCompressSpinBox->setValue(20.000000000000000);

        hboxLayout36->addWidget(quantiserBeforeCompressSpinBox);

        spacer_50 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout36->addItem(spacer_50);


        gridLayout7->addLayout(hboxLayout36, 0, 1, 1, 1);

        hboxLayout37 = new QHBoxLayout();
        hboxLayout37->setObjectName(QString::fromUtf8("hboxLayout37"));
        quantiserAfterCompressSpinBox = new QDoubleSpinBox(groupBoxQuantCurveCompress);
        quantiserAfterCompressSpinBox->setObjectName(QString::fromUtf8("quantiserAfterCompressSpinBox"));
        quantiserAfterCompressSpinBox->setDecimals(1);
        quantiserAfterCompressSpinBox->setMaximum(1.000000000000000);
        quantiserAfterCompressSpinBox->setSingleStep(0.100000000000000);
        quantiserAfterCompressSpinBox->setValue(0.500000000000000);

        hboxLayout37->addWidget(quantiserAfterCompressSpinBox);

        spacer_48 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout37->addItem(spacer_48);


        gridLayout7->addLayout(hboxLayout37, 1, 1, 1, 1);

        label_22 = new QLabel(groupBoxQuantCurveCompress);
        label_22->setObjectName(QString::fromUtf8("label_22"));

        gridLayout7->addWidget(label_22, 1, 0, 1, 1);


        vboxLayout13->addLayout(gridLayout7);


        verticalLayout_9->addWidget(groupBoxQuantCurveCompress);

        aqGroupBox = new QGroupBox(tabQuantiser);
        aqGroupBox->setObjectName(QString::fromUtf8("aqGroupBox"));
        verticalLayout_8 = new QVBoxLayout(aqGroupBox);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        aqVarianceCheckBox = new QCheckBox(aqGroupBox);
        aqVarianceCheckBox->setObjectName(QString::fromUtf8("aqVarianceCheckBox"));

        gridLayout_4->addWidget(aqVarianceCheckBox, 0, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        aqAlgoComboBox = new QComboBox(aqGroupBox);
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->addItem(QString());
        aqAlgoComboBox->setObjectName(QString::fromUtf8("aqAlgoComboBox"));
        aqAlgoComboBox->setEnabled(false);

        horizontalLayout_6->addWidget(aqAlgoComboBox);

        spacer_47 = new QSpacerItem(208, 13, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(spacer_47);


        gridLayout_4->addLayout(horizontalLayout_6, 0, 1, 1, 1);

        aqStrengthLabel = new QLabel(aqGroupBox);
        aqStrengthLabel->setObjectName(QString::fromUtf8("aqStrengthLabel"));
        aqStrengthLabel->setEnabled(false);

        gridLayout_4->addWidget(aqStrengthLabel, 1, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        aqStrengthSpinBox = new QDoubleSpinBox(aqGroupBox);
        aqStrengthSpinBox->setObjectName(QString::fromUtf8("aqStrengthSpinBox"));
        aqStrengthSpinBox->setEnabled(false);
        aqStrengthSpinBox->setDecimals(2);
        aqStrengthSpinBox->setMinimum(0.500000000000000);
        aqStrengthSpinBox->setMaximum(1.500000000000000);
        aqStrengthSpinBox->setSingleStep(0.100000000000000);
        aqStrengthSpinBox->setValue(1.000000000000000);

        horizontalLayout_7->addWidget(aqStrengthSpinBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout_4->addLayout(horizontalLayout_7, 1, 1, 1, 1);


        verticalLayout_8->addLayout(gridLayout_4);


        verticalLayout_9->addWidget(aqGroupBox);

        spacer_52 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_9->addItem(spacer_52);

        tabWidget->addTab(tabQuantiser, QString());
        tabAdvanced1 = new QWidget();
        tabAdvanced1->setObjectName(QString::fromUtf8("tabAdvanced1"));
        vboxLayout14 = new QVBoxLayout(tabAdvanced1);
        vboxLayout14->setObjectName(QString::fromUtf8("vboxLayout14"));
        groupBox = new QGroupBox(tabAdvanced1);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        vboxLayout15 = new QVBoxLayout(groupBox);
        vboxLayout15->setObjectName(QString::fromUtf8("vboxLayout15"));
        gridLayout8 = new QGridLayout();
        gridLayout8->setObjectName(QString::fromUtf8("gridLayout8"));
        label_9 = new QLabel(groupBox);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout8->addWidget(label_9, 0, 0, 1, 1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName(QString::fromUtf8("label_14"));

        gridLayout8->addWidget(label_14, 2, 0, 1, 1);

        hboxLayout38 = new QHBoxLayout();
        hboxLayout38->setObjectName(QString::fromUtf8("hboxLayout38"));
        vbvBufferSizeSpinBox = new QSpinBox(groupBox);
        vbvBufferSizeSpinBox->setObjectName(QString::fromUtf8("vbvBufferSizeSpinBox"));
        vbvBufferSizeSpinBox->setMaximum(99999);

        hboxLayout38->addWidget(vbvBufferSizeSpinBox);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        hboxLayout38->addWidget(label_12);

        spacer_55 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout38->addItem(spacer_55);


        gridLayout8->addLayout(hboxLayout38, 1, 1, 1, 1);

        hboxLayout39 = new QHBoxLayout();
        hboxLayout39->setObjectName(QString::fromUtf8("hboxLayout39"));
        vbvBufferOccupancySpinBox = new QSpinBox(groupBox);
        vbvBufferOccupancySpinBox->setObjectName(QString::fromUtf8("vbvBufferOccupancySpinBox"));
        vbvBufferOccupancySpinBox->setMaximum(100);
        vbvBufferOccupancySpinBox->setValue(90);

        hboxLayout39->addWidget(vbvBufferOccupancySpinBox);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        hboxLayout39->addWidget(label_13);

        spacer_58 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout39->addItem(spacer_58);


        gridLayout8->addLayout(hboxLayout39, 2, 1, 1, 1);

        hboxLayout40 = new QHBoxLayout();
        hboxLayout40->setObjectName(QString::fromUtf8("hboxLayout40"));
        vbvMaxBitrateSpinBox = new QSpinBox(groupBox);
        vbvMaxBitrateSpinBox->setObjectName(QString::fromUtf8("vbvMaxBitrateSpinBox"));
        vbvMaxBitrateSpinBox->setMaximum(99999);

        hboxLayout40->addWidget(vbvMaxBitrateSpinBox);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        hboxLayout40->addWidget(label_10);

        spacer_56 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout40->addItem(spacer_56);


        gridLayout8->addLayout(hboxLayout40, 0, 1, 1, 1);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        gridLayout8->addWidget(label_11, 1, 0, 1, 1);


        vboxLayout15->addLayout(gridLayout8);


        vboxLayout14->addWidget(groupBox);

        slicingGroupBox = new QGroupBox(tabAdvanced1);
        slicingGroupBox->setObjectName(QString::fromUtf8("slicingGroupBox"));
        gridLayout9 = new QGridLayout(slicingGroupBox);
        gridLayout9->setObjectName(QString::fromUtf8("gridLayout9"));
        label_25 = new QLabel(slicingGroupBox);
        label_25->setObjectName(QString::fromUtf8("label_25"));

        gridLayout9->addWidget(label_25, 2, 0, 1, 1);

        label_23 = new QLabel(slicingGroupBox);
        label_23->setObjectName(QString::fromUtf8("label_23"));

        gridLayout9->addWidget(label_23, 0, 0, 1, 1);

        hboxLayout41 = new QHBoxLayout();
        hboxLayout41->setObjectName(QString::fromUtf8("hboxLayout41"));
        maxSliceSizeSpinBox = new QSpinBox(slicingGroupBox);
        maxSliceSizeSpinBox->setObjectName(QString::fromUtf8("maxSliceSizeSpinBox"));
        maxSliceSizeSpinBox->setMaximum(2147483647);

        hboxLayout41->addWidget(maxSliceSizeSpinBox);

        label_32 = new QLabel(slicingGroupBox);
        label_32->setObjectName(QString::fromUtf8("label_32"));

        hboxLayout41->addWidget(label_32);

        spacer_54 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout41->addItem(spacer_54);


        gridLayout9->addLayout(hboxLayout41, 0, 1, 1, 2);

        label_24 = new QLabel(slicingGroupBox);
        label_24->setObjectName(QString::fromUtf8("label_24"));

        gridLayout9->addWidget(label_24, 1, 0, 1, 1);

        hboxLayout42 = new QHBoxLayout();
        hboxLayout42->setObjectName(QString::fromUtf8("hboxLayout42"));
        maxSliceMbSpinBox = new QSpinBox(slicingGroupBox);
        maxSliceMbSpinBox->setObjectName(QString::fromUtf8("maxSliceMbSpinBox"));
        maxSliceMbSpinBox->setMaximum(2147483647);

        hboxLayout42->addWidget(maxSliceMbSpinBox);

        spacer_57 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout42->addItem(spacer_57);


        gridLayout9->addLayout(hboxLayout42, 1, 1, 1, 1);

        hboxLayout43 = new QHBoxLayout();
        hboxLayout43->setObjectName(QString::fromUtf8("hboxLayout43"));
        slicesPerFrameSpinBox = new QSpinBox(slicingGroupBox);
        slicesPerFrameSpinBox->setObjectName(QString::fromUtf8("slicesPerFrameSpinBox"));
        slicesPerFrameSpinBox->setMaximum(2147483647);

        hboxLayout43->addWidget(slicesPerFrameSpinBox);

        spacer_53 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout43->addItem(spacer_53);


        gridLayout9->addLayout(hboxLayout43, 2, 1, 1, 1);


        vboxLayout14->addWidget(slicingGroupBox);

        groupBoxZones = new QGroupBox(tabAdvanced1);
        groupBoxZones->setObjectName(QString::fromUtf8("groupBoxZones"));
        vboxLayout16 = new QVBoxLayout(groupBoxZones);
        vboxLayout16->setObjectName(QString::fromUtf8("vboxLayout16"));
        _12 = new QHBoxLayout();
        _12->setObjectName(QString::fromUtf8("_12"));
        zoneTableView = new QTableView(groupBoxZones);
        zoneTableView->setObjectName(QString::fromUtf8("zoneTableView"));
        zoneTableView->setSelectionMode(QAbstractItemView::SingleSelection);
        zoneTableView->setSelectionBehavior(QAbstractItemView::SelectRows);

        _12->addWidget(zoneTableView);

        _13 = new QVBoxLayout();
        _13->setObjectName(QString::fromUtf8("_13"));
        zoneAddButton = new QPushButton(groupBoxZones);
        zoneAddButton->setObjectName(QString::fromUtf8("zoneAddButton"));

        _13->addWidget(zoneAddButton);

        zoneEditButton = new QPushButton(groupBoxZones);
        zoneEditButton->setObjectName(QString::fromUtf8("zoneEditButton"));

        _13->addWidget(zoneEditButton);

        zoneDeleteButton = new QPushButton(groupBoxZones);
        zoneDeleteButton->setObjectName(QString::fromUtf8("zoneDeleteButton"));

        _13->addWidget(zoneDeleteButton);

        spacer_59 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        _13->addItem(spacer_59);


        _12->addLayout(_13);


        vboxLayout16->addLayout(_12);


        vboxLayout14->addWidget(groupBoxZones);

        tabWidget->addTab(tabAdvanced1, QString());
        tabAdvanced2 = new QWidget();
        tabAdvanced2->setObjectName(QString::fromUtf8("tabAdvanced2"));
        verticalLayout_4 = new QVBoxLayout(tabAdvanced2);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        groupBoxThreads = new QGroupBox(tabAdvanced2);
        groupBoxThreads->setObjectName(QString::fromUtf8("groupBoxThreads"));
        _2 = new QVBoxLayout(groupBoxThreads);
        _2->setObjectName(QString::fromUtf8("_2"));
        _4 = new QVBoxLayout();
        _4->setObjectName(QString::fromUtf8("_4"));
        threadDisableRadioButton = new QRadioButton(groupBoxThreads);
        threadDisableRadioButton->setObjectName(QString::fromUtf8("threadDisableRadioButton"));

        _4->addWidget(threadDisableRadioButton);

        threadAutoDetectRadioButton = new QRadioButton(groupBoxThreads);
        threadAutoDetectRadioButton->setObjectName(QString::fromUtf8("threadAutoDetectRadioButton"));
        threadAutoDetectRadioButton->setChecked(true);

        _4->addWidget(threadAutoDetectRadioButton);

        _14 = new QHBoxLayout();
        _14->setObjectName(QString::fromUtf8("_14"));
        threadCustomRadioButton = new QRadioButton(groupBoxThreads);
        threadCustomRadioButton->setObjectName(QString::fromUtf8("threadCustomRadioButton"));

        _14->addWidget(threadCustomRadioButton);

        threadCustomSpinBox = new QSpinBox(groupBoxThreads);
        threadCustomSpinBox->setObjectName(QString::fromUtf8("threadCustomSpinBox"));
        threadCustomSpinBox->setEnabled(false);
        threadCustomSpinBox->setMinimum(2);
        threadCustomSpinBox->setMaximum(32);

        _14->addWidget(threadCustomSpinBox);

        spacer_2 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _14->addItem(spacer_2);


        _4->addLayout(_14);


        _2->addLayout(_4);

        repeatabilityCheckBox = new QCheckBox(groupBoxThreads);
        repeatabilityCheckBox->setObjectName(QString::fromUtf8("repeatabilityCheckBox"));

        _2->addWidget(repeatabilityCheckBox);

        sliceThreadingCheckBox = new QCheckBox(groupBoxThreads);
        sliceThreadingCheckBox->setObjectName(QString::fromUtf8("sliceThreadingCheckBox"));

        _2->addWidget(sliceThreadingCheckBox);

        _15 = new QHBoxLayout();
        _15->setObjectName(QString::fromUtf8("_15"));
        threadedLookaheadCheckBox = new QCheckBox(groupBoxThreads);
        threadedLookaheadCheckBox->setObjectName(QString::fromUtf8("threadedLookaheadCheckBox"));

        _15->addWidget(threadedLookaheadCheckBox);

        threadedLookaheadSpinBox = new QSpinBox(groupBoxThreads);
        threadedLookaheadSpinBox->setObjectName(QString::fromUtf8("threadedLookaheadSpinBox"));
        threadedLookaheadSpinBox->setEnabled(false);
        threadedLookaheadSpinBox->setMaximum(250);

        _15->addWidget(threadedLookaheadSpinBox);

        lblThreadedFrames = new QLabel(groupBoxThreads);
        lblThreadedFrames->setObjectName(QString::fromUtf8("lblThreadedFrames"));
        lblThreadedFrames->setEnabled(false);

        _15->addWidget(lblThreadedFrames);

        spacer = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _15->addItem(spacer);


        _2->addLayout(_15);


        verticalLayout_4->addWidget(groupBoxThreads);

        verticalSpacer = new QSpacerItem(20, 256, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        tabWidget->addTab(tabAdvanced2, QString());
        tabOutput1 = new QWidget();
        tabOutput1->setObjectName(QString::fromUtf8("tabOutput1"));
        vboxLayout17 = new QVBoxLayout(tabOutput1);
        vboxLayout17->setObjectName(QString::fromUtf8("vboxLayout17"));
        groupBoxOutput = new QGroupBox(tabOutput1);
        groupBoxOutput->setObjectName(QString::fromUtf8("groupBoxOutput"));
        vboxLayout18 = new QVBoxLayout(groupBoxOutput);
        vboxLayout18->setObjectName(QString::fromUtf8("vboxLayout18"));
        accessUnitCheckBox = new QCheckBox(groupBoxOutput);
        accessUnitCheckBox->setObjectName(QString::fromUtf8("accessUnitCheckBox"));

        vboxLayout18->addWidget(accessUnitCheckBox);

        blueRayCompat = new QCheckBox(groupBoxOutput);
        blueRayCompat->setObjectName(QString::fromUtf8("blueRayCompat"));

        vboxLayout18->addWidget(blueRayCompat);

        fakeInterlaced = new QCheckBox(groupBoxOutput);
        fakeInterlaced->setObjectName(QString::fromUtf8("fakeInterlaced"));

        vboxLayout18->addWidget(fakeInterlaced);


        vboxLayout17->addWidget(groupBoxOutput);

        groupBoxAspectRatio = new QGroupBox(tabOutput1);
        groupBoxAspectRatio->setObjectName(QString::fromUtf8("groupBoxAspectRatio"));
        vboxLayout19 = new QVBoxLayout(groupBoxAspectRatio);
        vboxLayout19->setObjectName(QString::fromUtf8("vboxLayout19"));
        gridLayout10 = new QGridLayout();
        gridLayout10->setObjectName(QString::fromUtf8("gridLayout10"));
        sarCustomRadioButton = new QRadioButton(groupBoxAspectRatio);
        sarCustomRadioButton->setObjectName(QString::fromUtf8("sarCustomRadioButton"));
        sarCustomRadioButton->setChecked(true);

        gridLayout10->addWidget(sarCustomRadioButton, 0, 0, 1, 1);

        sarAsInputRadioButton = new QRadioButton(groupBoxAspectRatio);
        sarAsInputRadioButton->setObjectName(QString::fromUtf8("sarAsInputRadioButton"));

        gridLayout10->addWidget(sarAsInputRadioButton, 2, 0, 1, 1);

        hboxLayout44 = new QHBoxLayout();
        hboxLayout44->setObjectName(QString::fromUtf8("hboxLayout44"));
        sarAsInputLabel = new QLabel(groupBoxAspectRatio);
        sarAsInputLabel->setObjectName(QString::fromUtf8("sarAsInputLabel"));
        sarAsInputLabel->setEnabled(false);

        hboxLayout44->addWidget(sarAsInputLabel);

        spacer_65 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout44->addItem(spacer_65);


        gridLayout10->addLayout(hboxLayout44, 2, 1, 1, 1);

        hboxLayout45 = new QHBoxLayout();
        hboxLayout45->setObjectName(QString::fromUtf8("hboxLayout45"));
        sarCustomSpinBox1 = new QSpinBox(groupBoxAspectRatio);
        sarCustomSpinBox1->setObjectName(QString::fromUtf8("sarCustomSpinBox1"));
        sarCustomSpinBox1->setMinimum(1);
        sarCustomSpinBox1->setMaximum(9999);
        sarCustomSpinBox1->setValue(1);

        hboxLayout45->addWidget(sarCustomSpinBox1);

        sarCustomLabel = new QLabel(groupBoxAspectRatio);
        sarCustomLabel->setObjectName(QString::fromUtf8("sarCustomLabel"));

        hboxLayout45->addWidget(sarCustomLabel);

        sarCustomSpinBox2 = new QSpinBox(groupBoxAspectRatio);
        sarCustomSpinBox2->setObjectName(QString::fromUtf8("sarCustomSpinBox2"));
        sarCustomSpinBox2->setMinimum(1);
        sarCustomSpinBox2->setMaximum(9999);
        sarCustomSpinBox2->setValue(1);

        hboxLayout45->addWidget(sarCustomSpinBox2);

        spacer_64 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout45->addItem(spacer_64);


        gridLayout10->addLayout(hboxLayout45, 0, 1, 1, 1);

        sarPredefinedRadioButton = new QRadioButton(groupBoxAspectRatio);
        sarPredefinedRadioButton->setObjectName(QString::fromUtf8("sarPredefinedRadioButton"));

        gridLayout10->addWidget(sarPredefinedRadioButton, 1, 0, 1, 1);

        hboxLayout46 = new QHBoxLayout();
        hboxLayout46->setObjectName(QString::fromUtf8("hboxLayout46"));
        sarPredefinedComboBox = new QComboBox(groupBoxAspectRatio);
        sarPredefinedComboBox->addItem(QString());
        sarPredefinedComboBox->addItem(QString());
        sarPredefinedComboBox->addItem(QString());
        sarPredefinedComboBox->addItem(QString());
        sarPredefinedComboBox->setObjectName(QString::fromUtf8("sarPredefinedComboBox"));
        sarPredefinedComboBox->setEnabled(false);

        hboxLayout46->addWidget(sarPredefinedComboBox);

        spacer_62 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout46->addItem(spacer_62);


        gridLayout10->addLayout(hboxLayout46, 1, 1, 1, 1);


        vboxLayout19->addLayout(gridLayout10);


        vboxLayout17->addWidget(groupBoxAspectRatio);

        spacer_60 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout17->addItem(spacer_60);

        tabWidget->addTab(tabOutput1, QString());
        tabOutput2 = new QWidget();
        tabOutput2->setObjectName(QString::fromUtf8("tabOutput2"));
        verticalLayout = new QVBoxLayout(tabOutput2);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBoxVui = new QGroupBox(tabOutput2);
        groupBoxVui->setObjectName(QString::fromUtf8("groupBoxVui"));
        verticalLayout_2 = new QVBoxLayout(groupBoxVui);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label_52 = new QLabel(groupBoxVui);
        label_52->setObjectName(QString::fromUtf8("label_52"));
        label_52->setWordWrap(true);

        verticalLayout_2->addWidget(label_52);

        spacerItem5 = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_2->addItem(spacerItem5);

        gridLayout11 = new QGridLayout();
        gridLayout11->setObjectName(QString::fromUtf8("gridLayout11"));
        label_51 = new QLabel(groupBoxVui);
        label_51->setObjectName(QString::fromUtf8("label_51"));

        gridLayout11->addWidget(label_51, 0, 0, 1, 1);

        _6 = new QHBoxLayout();
        _6->setObjectName(QString::fromUtf8("_6"));
        overscanComboBox = new QComboBox(groupBoxVui);
        overscanComboBox->addItem(QString());
        overscanComboBox->addItem(QString());
        overscanComboBox->addItem(QString());
        overscanComboBox->setObjectName(QString::fromUtf8("overscanComboBox"));

        _6->addWidget(overscanComboBox);

        spacer_70 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _6->addItem(spacer_70);


        gridLayout11->addLayout(_6, 0, 1, 1, 1);

        label_50 = new QLabel(groupBoxVui);
        label_50->setObjectName(QString::fromUtf8("label_50"));

        gridLayout11->addWidget(label_50, 1, 0, 1, 1);

        _8 = new QHBoxLayout();
        _8->setObjectName(QString::fromUtf8("_8"));
        videoFormatComboBox = new QComboBox(groupBoxVui);
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->addItem(QString());
        videoFormatComboBox->setObjectName(QString::fromUtf8("videoFormatComboBox"));

        _8->addWidget(videoFormatComboBox);

        spacer_68 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _8->addItem(spacer_68);


        gridLayout11->addLayout(_8, 1, 1, 1, 1);

        label_19 = new QLabel(groupBoxVui);
        label_19->setObjectName(QString::fromUtf8("label_19"));

        gridLayout11->addWidget(label_19, 2, 0, 1, 1);

        _9 = new QHBoxLayout();
        _9->setObjectName(QString::fromUtf8("_9"));
        colourPrimariesComboBox = new QComboBox(groupBoxVui);
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->addItem(QString());
        colourPrimariesComboBox->setObjectName(QString::fromUtf8("colourPrimariesComboBox"));

        _9->addWidget(colourPrimariesComboBox);

        spacer_69 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _9->addItem(spacer_69);


        gridLayout11->addLayout(_9, 2, 1, 1, 1);

        label_48 = new QLabel(groupBoxVui);
        label_48->setObjectName(QString::fromUtf8("label_48"));

        gridLayout11->addWidget(label_48, 3, 0, 1, 1);

        _5 = new QHBoxLayout();
        _5->setObjectName(QString::fromUtf8("_5"));
        transferCharacteristicsComboBox = new QComboBox(groupBoxVui);
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->addItem(QString());
        transferCharacteristicsComboBox->setObjectName(QString::fromUtf8("transferCharacteristicsComboBox"));

        _5->addWidget(transferCharacteristicsComboBox);

        spacer_67 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _5->addItem(spacer_67);


        gridLayout11->addLayout(_5, 3, 1, 1, 1);

        label_47 = new QLabel(groupBoxVui);
        label_47->setObjectName(QString::fromUtf8("label_47"));

        gridLayout11->addWidget(label_47, 4, 0, 1, 1);

        _7 = new QHBoxLayout();
        _7->setObjectName(QString::fromUtf8("_7"));
        colourMatrixComboBox = new QComboBox(groupBoxVui);
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->addItem(QString());
        colourMatrixComboBox->setObjectName(QString::fromUtf8("colourMatrixComboBox"));

        _7->addWidget(colourMatrixComboBox);

        spacer_71 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _7->addItem(spacer_71);


        gridLayout11->addLayout(_7, 4, 1, 1, 1);

        hrdLabel = new QLabel(groupBoxVui);
        hrdLabel->setObjectName(QString::fromUtf8("hrdLabel"));

        gridLayout11->addWidget(hrdLabel, 5, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        hrdComboBox = new QComboBox(groupBoxVui);
        hrdComboBox->addItem(QString());
        hrdComboBox->addItem(QString());
        hrdComboBox->addItem(QString());
        hrdComboBox->setObjectName(QString::fromUtf8("hrdComboBox"));

        horizontalLayout_3->addWidget(hrdComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        gridLayout11->addLayout(horizontalLayout_3, 5, 1, 1, 1);

        label_49 = new QLabel(groupBoxVui);
        label_49->setObjectName(QString::fromUtf8("label_49"));

        gridLayout11->addWidget(label_49, 6, 0, 1, 1);

        _10 = new QHBoxLayout();
        _10->setObjectName(QString::fromUtf8("_10"));
        chromaSampleSpinBox = new QSpinBox(groupBoxVui);
        chromaSampleSpinBox->setObjectName(QString::fromUtf8("chromaSampleSpinBox"));
        chromaSampleSpinBox->setMaximum(4);

        _10->addWidget(chromaSampleSpinBox);

        spacer_66 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _10->addItem(spacer_66);


        gridLayout11->addLayout(_10, 6, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout11);

        fullRangeSamplesCheckBox = new QCheckBox(groupBoxVui);
        fullRangeSamplesCheckBox->setObjectName(QString::fromUtf8("fullRangeSamplesCheckBox"));

        verticalLayout_2->addWidget(fullRangeSamplesCheckBox);


        verticalLayout->addWidget(groupBoxVui);

        spacer_72 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacer_72);

        tabWidget->addTab(tabOutput2, QString());

        _11->addWidget(tabWidget);

        hboxLayout47 = new QHBoxLayout();
        hboxLayout47->setObjectName(QString::fromUtf8("hboxLayout47"));
        buttonBox = new QDialogButtonBox(x264ConfigDialog);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        hboxLayout47->addWidget(buttonBox);


        _11->addLayout(hboxLayout47);

        QWidget::setTabOrder(configurationComboBox, saveAsButton);
        QWidget::setTabOrder(saveAsButton, deleteButton);
        QWidget::setTabOrder(deleteButton, tabWidget);
        QWidget::setTabOrder(tabWidget, encodingModeComboBox);
        QWidget::setTabOrder(encodingModeComboBox, targetRateControlSpinBox);
        QWidget::setTabOrder(targetRateControlSpinBox, quantiserSlider);
        QWidget::setTabOrder(quantiserSlider, quantiserSpinBox);
        QWidget::setTabOrder(quantiserSpinBox, psychoTrellisSpinBox);
        QWidget::setTabOrder(psychoTrellisSpinBox, meMethodComboBox);
        QWidget::setTabOrder(meMethodComboBox, meSlider);
        QWidget::setTabOrder(meSlider, meSpinBox);
        QWidget::setTabOrder(meSpinBox, mvRangeSpinBox);
        QWidget::setTabOrder(mvRangeSpinBox, mvLengthCheckBox);
        QWidget::setTabOrder(mvLengthCheckBox, mvLengthSpinBox);
        QWidget::setTabOrder(mvLengthSpinBox, minThreadBufferCheckBox);
        QWidget::setTabOrder(minThreadBufferCheckBox, minThreadBufferSpinBox);
        QWidget::setTabOrder(minThreadBufferSpinBox, predictModeComboBox);
        QWidget::setTabOrder(predictModeComboBox, weightedPPredictComboBox);
        QWidget::setTabOrder(weightedPPredictComboBox, weightedPredictCheckBox);
        QWidget::setTabOrder(weightedPredictCheckBox, constrainedIntraCheckBox);
        QWidget::setTabOrder(constrainedIntraCheckBox, dct8x8CheckBox);
        QWidget::setTabOrder(dct8x8CheckBox, p8x8CheckBox);
        QWidget::setTabOrder(p8x8CheckBox, b8x8CheckBox);
        QWidget::setTabOrder(b8x8CheckBox, p4x4CheckBox);
        QWidget::setTabOrder(p4x4CheckBox, i8x8CheckBox);
        QWidget::setTabOrder(i8x8CheckBox, i4x4CheckBox);
        QWidget::setTabOrder(i4x4CheckBox, cabacCheckBox);
        QWidget::setTabOrder(cabacCheckBox, loopFilterCheckBox);
        QWidget::setTabOrder(loopFilterCheckBox, alphaC0SpinBox);
        QWidget::setTabOrder(alphaC0SpinBox, betaSpinBox);
        QWidget::setTabOrder(betaSpinBox, openGopCheckBox);
        QWidget::setTabOrder(openGopCheckBox, openGopComboBox);
        QWidget::setTabOrder(openGopComboBox, interlacedCheckBox);
        QWidget::setTabOrder(interlacedCheckBox, interlacedComboBox);
        QWidget::setTabOrder(interlacedComboBox, refFramesSpinBox);
        QWidget::setTabOrder(refFramesSpinBox, maxBFramesSpinBox);
        QWidget::setTabOrder(maxBFramesSpinBox, BFrameBiasSpinBox);
        QWidget::setTabOrder(BFrameBiasSpinBox, adaptiveBFrameComboBox);
        QWidget::setTabOrder(adaptiveBFrameComboBox, bFrameRefComboBox);
        QWidget::setTabOrder(bFrameRefComboBox, minGopSizeSpinBox);
        QWidget::setTabOrder(minGopSizeSpinBox, maxGopSizeSpinBox);
        QWidget::setTabOrder(maxGopSizeSpinBox, IFrameThresholdSpinBox);
        QWidget::setTabOrder(IFrameThresholdSpinBox, intraRefreshCheckBox);
        QWidget::setTabOrder(intraRefreshCheckBox, mixedRefsCheckBox);
        QWidget::setTabOrder(mixedRefsCheckBox, chromaMotionEstCheckBox);
        QWidget::setTabOrder(chromaMotionEstCheckBox, trellisCheckBox);
        QWidget::setTabOrder(trellisCheckBox, trellisComboBox);
        QWidget::setTabOrder(trellisComboBox, fastPSkipCheckBox);
        QWidget::setTabOrder(fastPSkipCheckBox, dctDecimateCheckBox);
        QWidget::setTabOrder(dctDecimateCheckBox, psychoRdoSpinBox);
        QWidget::setTabOrder(psychoRdoSpinBox, noiseReductionSpinBox);
        QWidget::setTabOrder(noiseReductionSpinBox, intraLumaSpinBox);
        QWidget::setTabOrder(intraLumaSpinBox, interLumaSpinBox);
        QWidget::setTabOrder(interLumaSpinBox, matrixFlatRadioButton);
        QWidget::setTabOrder(matrixFlatRadioButton, matrixJvtRadioButton);
        QWidget::setTabOrder(matrixJvtRadioButton, matrixCustomRadioButton);
        QWidget::setTabOrder(matrixCustomRadioButton, matrixCustomEditButton);
        QWidget::setTabOrder(matrixCustomEditButton, quantiserMinSpinBox);
        QWidget::setTabOrder(quantiserMinSpinBox, quantiserMaxSpinBox);
        QWidget::setTabOrder(quantiserMaxSpinBox, quantiserMaxStepSpinBox);
        QWidget::setTabOrder(quantiserMaxStepSpinBox, avgBitrateToleranceSpinBox);
        QWidget::setTabOrder(avgBitrateToleranceSpinBox, quantiserIpRatioSpinBox);
        QWidget::setTabOrder(quantiserIpRatioSpinBox, quantiserPbRatioSpinBox);
        QWidget::setTabOrder(quantiserPbRatioSpinBox, chromaLumaOffsetSpinBox);
        QWidget::setTabOrder(chromaLumaOffsetSpinBox, quantiserCurveCompressSpinBox);
        QWidget::setTabOrder(quantiserCurveCompressSpinBox, quantiserBeforeCompressSpinBox);
        QWidget::setTabOrder(quantiserBeforeCompressSpinBox, quantiserAfterCompressSpinBox);
        QWidget::setTabOrder(quantiserAfterCompressSpinBox, aqVarianceCheckBox);
        QWidget::setTabOrder(aqVarianceCheckBox, aqAlgoComboBox);
        QWidget::setTabOrder(aqAlgoComboBox, aqStrengthSpinBox);
        QWidget::setTabOrder(aqStrengthSpinBox, vbvMaxBitrateSpinBox);
        QWidget::setTabOrder(vbvMaxBitrateSpinBox, vbvBufferSizeSpinBox);
        QWidget::setTabOrder(vbvBufferSizeSpinBox, vbvBufferOccupancySpinBox);
        QWidget::setTabOrder(vbvBufferOccupancySpinBox, maxSliceSizeSpinBox);
        QWidget::setTabOrder(maxSliceSizeSpinBox, maxSliceMbSpinBox);
        QWidget::setTabOrder(maxSliceMbSpinBox, slicesPerFrameSpinBox);
        QWidget::setTabOrder(slicesPerFrameSpinBox, zoneTableView);
        QWidget::setTabOrder(zoneTableView, zoneAddButton);
        QWidget::setTabOrder(zoneAddButton, zoneEditButton);
        QWidget::setTabOrder(zoneEditButton, zoneDeleteButton);
        QWidget::setTabOrder(zoneDeleteButton, threadDisableRadioButton);
        QWidget::setTabOrder(threadDisableRadioButton, threadAutoDetectRadioButton);
        QWidget::setTabOrder(threadAutoDetectRadioButton, threadCustomRadioButton);
        QWidget::setTabOrder(threadCustomRadioButton, threadCustomSpinBox);
        QWidget::setTabOrder(threadCustomSpinBox, repeatabilityCheckBox);
        QWidget::setTabOrder(repeatabilityCheckBox, sliceThreadingCheckBox);
        QWidget::setTabOrder(sliceThreadingCheckBox, threadedLookaheadCheckBox);
        QWidget::setTabOrder(threadedLookaheadCheckBox, threadedLookaheadSpinBox);
        QWidget::setTabOrder(threadedLookaheadSpinBox, accessUnitCheckBox);
        QWidget::setTabOrder(accessUnitCheckBox, sarCustomRadioButton);
        QWidget::setTabOrder(sarCustomRadioButton, sarCustomSpinBox1);
        QWidget::setTabOrder(sarCustomSpinBox1, sarCustomSpinBox2);
        QWidget::setTabOrder(sarCustomSpinBox2, sarPredefinedRadioButton);
        QWidget::setTabOrder(sarPredefinedRadioButton, sarPredefinedComboBox);
        QWidget::setTabOrder(sarPredefinedComboBox, sarAsInputRadioButton);
        QWidget::setTabOrder(sarAsInputRadioButton, overscanComboBox);
        QWidget::setTabOrder(overscanComboBox, videoFormatComboBox);
        QWidget::setTabOrder(videoFormatComboBox, colourPrimariesComboBox);
        QWidget::setTabOrder(colourPrimariesComboBox, transferCharacteristicsComboBox);
        QWidget::setTabOrder(transferCharacteristicsComboBox, colourMatrixComboBox);
        QWidget::setTabOrder(colourMatrixComboBox, hrdComboBox);
        QWidget::setTabOrder(hrdComboBox, chromaSampleSpinBox);
        QWidget::setTabOrder(chromaSampleSpinBox, fullRangeSamplesCheckBox);
        QWidget::setTabOrder(fullRangeSamplesCheckBox, buttonBox);

        retranslateUi(x264ConfigDialog);
        QObject::connect(sarPredefinedRadioButton, SIGNAL(toggled(bool)), sarPredefinedComboBox, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomSpinBox1, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomSpinBox2, SLOT(setEnabled(bool)));
        QObject::connect(sarCustomRadioButton, SIGNAL(toggled(bool)), sarCustomLabel, SLOT(setEnabled(bool)));
        QObject::connect(mvLengthCheckBox, SIGNAL(toggled(bool)), mvLengthSpinBox, SLOT(setEnabled(bool)));
        QObject::connect(minThreadBufferCheckBox, SIGNAL(toggled(bool)), minThreadBufferSpinBox, SLOT(setEnabled(bool)));
        QObject::connect(p8x8CheckBox, SIGNAL(toggled(bool)), p4x4CheckBox, SLOT(setEnabled(bool)));
        QObject::connect(dct8x8CheckBox, SIGNAL(toggled(bool)), i8x8CheckBox, SLOT(setEnabled(bool)));
        QObject::connect(trellisCheckBox, SIGNAL(toggled(bool)), trellisComboBox, SLOT(setEnabled(bool)));
        QObject::connect(matrixCustomRadioButton, SIGNAL(toggled(bool)), matrixCustomEditButton, SLOT(setEnabled(bool)));
        QObject::connect(sarAsInputRadioButton, SIGNAL(toggled(bool)), sarAsInputLabel, SLOT(setEnabled(bool)));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqStrengthLabel, SLOT(setEnabled(bool)));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqStrengthSpinBox, SLOT(setEnabled(bool)));
        QObject::connect(buttonBox, SIGNAL(accepted()), x264ConfigDialog, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), x264ConfigDialog, SLOT(reject()));
        QObject::connect(interlacedCheckBox, SIGNAL(toggled(bool)), interlacedComboBox, SLOT(setEnabled(bool)));
        QObject::connect(openGopCheckBox, SIGNAL(toggled(bool)), openGopComboBox, SLOT(setEnabled(bool)));
        QObject::connect(aqVarianceCheckBox, SIGNAL(toggled(bool)), aqAlgoComboBox, SLOT(setEnabled(bool)));
        QObject::connect(trellisCheckBox, SIGNAL(toggled(bool)), lblPsyTrellis, SLOT(setEnabled(bool)));
        QObject::connect(trellisCheckBox, SIGNAL(toggled(bool)), psychoTrellisSpinBox, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(7);
        presetComboBox->setCurrentIndex(-1);
        idcLevelComboBox->setCurrentIndex(0);
        encodingModeComboBox->setCurrentIndex(3);
        meMethodComboBox->setCurrentIndex(1);
        predictModeComboBox->setCurrentIndex(1);
        videoFormatComboBox->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(x264ConfigDialog);
    } // setupUi

    void retranslateUi(QDialog *x264ConfigDialog)
    {
        x264ConfigDialog->setWindowTitle(QCoreApplication::translate("x264ConfigDialog", "x264 Configuraton", nullptr));
        label_3->setText(QCoreApplication::translate("x264ConfigDialog", "Configuration:", nullptr));
        saveAsButton->setText(QCoreApplication::translate("x264ConfigDialog", "Save As", nullptr));
        deleteButton->setText(QCoreApplication::translate("x264ConfigDialog", "Delete", nullptr));
        groupBoxBasic->setTitle(QCoreApplication::translate("x264ConfigDialog", "Basic", nullptr));
        useAdvancedConfigurationCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Use advanced configuration", nullptr));
        label_46->setText(QCoreApplication::translate("x264ConfigDialog", "Profile:", nullptr));
        label_41->setText(QCoreApplication::translate("x264ConfigDialog", "Preset:", nullptr));
        label_45->setText(QCoreApplication::translate("x264ConfigDialog", "Tuning:", nullptr));
        label_53->setText(QCoreApplication::translate("x264ConfigDialog", "IDC Level:", nullptr));
        idcLevelComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Auto", nullptr));
        idcLevelComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "1", nullptr));
        idcLevelComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "1.1", nullptr));
        idcLevelComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "1.2", nullptr));
        idcLevelComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "1.3", nullptr));
        idcLevelComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "2", nullptr));
        idcLevelComboBox->setItemText(6, QCoreApplication::translate("x264ConfigDialog", "2.1", nullptr));
        idcLevelComboBox->setItemText(7, QCoreApplication::translate("x264ConfigDialog", "2.2", nullptr));
        idcLevelComboBox->setItemText(8, QCoreApplication::translate("x264ConfigDialog", "3", nullptr));
        idcLevelComboBox->setItemText(9, QCoreApplication::translate("x264ConfigDialog", "3.1", nullptr));
        idcLevelComboBox->setItemText(10, QCoreApplication::translate("x264ConfigDialog", "3.2", nullptr));
        idcLevelComboBox->setItemText(11, QCoreApplication::translate("x264ConfigDialog", "4", nullptr));
        idcLevelComboBox->setItemText(12, QCoreApplication::translate("x264ConfigDialog", "4.1", nullptr));
        idcLevelComboBox->setItemText(13, QCoreApplication::translate("x264ConfigDialog", "4.2", nullptr));
        idcLevelComboBox->setItemText(14, QCoreApplication::translate("x264ConfigDialog", "5", nullptr));
        idcLevelComboBox->setItemText(15, QCoreApplication::translate("x264ConfigDialog", "5.1", nullptr));

        fastDecodeCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Fast Decode", nullptr));
        zeroLatencyCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Zero Latency", nullptr));
        fastFirstPassCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Fast First Pass", nullptr));
        labelThread->setText(QCoreApplication::translate("x264ConfigDialog", "Threads ", nullptr));
        groupBoxRateControl->setTitle(QCoreApplication::translate("x264ConfigDialog", "Rate Control", nullptr));
        targetRateControlLabel1->setText(QCoreApplication::translate("x264ConfigDialog", "Target Video Size:", nullptr));
        encodingModeComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Constant Bitrate (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Constant Quantiser (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Constant Rate Factor (Single Pass)", nullptr));
        encodingModeComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "Video Size (Two Pass)", nullptr));
        encodingModeComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "Average Bitrate (Two Pass)", nullptr));

        label->setText(QCoreApplication::translate("x264ConfigDialog", "Encoding Mode:", nullptr));
        targetRateControlSpinBox->setPrefix(QString());
        targetRateControlLabel2->setText(QCoreApplication::translate("x264ConfigDialog", "MB", nullptr));
        quantiserLabel1->setText(QCoreApplication::translate("x264ConfigDialog", "0 (High Quality)", nullptr));
        quantiserLabel2->setText(QCoreApplication::translate("x264ConfigDialog", "Quantiser", nullptr));
        quantiserLabel3->setText(QCoreApplication::translate("x264ConfigDialog", "51 (Low Quality)", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGeneral), QCoreApplication::translate("x264ConfigDialog", "General", nullptr));
        groupBoxAdvRateControl->setTitle(QCoreApplication::translate("x264ConfigDialog", "Advanced Rate Control", nullptr));
        maxCrfCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Constant Rate Factor", nullptr));
        quantiserLabel1_2->setText(QCoreApplication::translate("x264ConfigDialog", "0 (High Quality)", nullptr));
        quantiserLabel2_2->setText(QCoreApplication::translate("x264ConfigDialog", "Quantiser", nullptr));
        quantiserLabel3_2->setText(QCoreApplication::translate("x264ConfigDialog", "51 (Low Quality)", nullptr));
        mbTreeCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Macroblock-tree Rate Control", nullptr));
        lblLookahead->setText(QCoreApplication::translate("x264ConfigDialog", "Frametype Lookahead:", nullptr));
        lblLookaheadFrames->setText(QCoreApplication::translate("x264ConfigDialog", "frames", nullptr));
        label_55->setText(QCoreApplication::translate("x264ConfigDialog", "Sequence Parameter Set Identifer:", nullptr));
        spsiComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "0", nullptr));
        spsiComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "1", nullptr));
        spsiComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "3", nullptr));
        spsiComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "7", nullptr));
        spsiComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "15", nullptr));
        spsiComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "31", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tabAdvancedRC), QCoreApplication::translate("x264ConfigDialog", "Advanced RC", nullptr));
        groupBoxMotionEstimation->setTitle(QCoreApplication::translate("x264ConfigDialog", "Motion Estimation", nullptr));
        label_38->setText(QCoreApplication::translate("x264ConfigDialog", "Motion Estimation Method:", nullptr));
        meMethodComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Diamond Search", nullptr));
        meMethodComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Hexagonal Search", nullptr));
        meMethodComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Uneven Multi-hexagonal Search", nullptr));
        meMethodComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "Exhaustive Search", nullptr));
        meMethodComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "Hadamard Exhaustive Search", nullptr));

        label_35->setText(QCoreApplication::translate("x264ConfigDialog", "1 (Fast)", nullptr));
        label_36->setText(QCoreApplication::translate("x264ConfigDialog", "Subpixel Refinement", nullptr));
        label_37->setText(QCoreApplication::translate("x264ConfigDialog", "11 (Best)", nullptr));
        groupBoxMV->setTitle(QCoreApplication::translate("x264ConfigDialog", "Motion Vector", nullptr));
        mvLengthCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Motion Vector Length:", nullptr));
        minThreadBufferCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Minimum Buffer Between Threads:", nullptr));
        label_39->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Motion Vector Search Range:", nullptr));
        groupBoxPred->setTitle(QCoreApplication::translate("x264ConfigDialog", "Prediction", nullptr));
        weightedPPredictComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Disabled", nullptr));
        weightedPPredictComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Weighted References", nullptr));
        weightedPPredictComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Weighted References + Duplicates", nullptr));

        label_40->setText(QCoreApplication::translate("x264ConfigDialog", "Direct Prediction Mode:", nullptr));
        lblWeightedPPredict->setText(QCoreApplication::translate("x264ConfigDialog", "Weighted Prediction for P-frames:", nullptr));
        predictModeComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "None", nullptr));
        predictModeComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Spatial", nullptr));
        predictModeComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Temporal", nullptr));
        predictModeComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "Auto", nullptr));

        weightedPredictCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Weighted Prediction for B-frames", nullptr));
        constrainedIntraCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Constrained Intra Prediction", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabMotion), QCoreApplication::translate("x264ConfigDialog", "Motion", nullptr));
        groupBoxPart->setTitle(QCoreApplication::translate("x264ConfigDialog", "Partition Search", nullptr));
        dct8x8CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "8x8 DCT Spatial Transform", nullptr));
        p8x8CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "8x8, 8x16 and 16x8 P-frame Intra-predicted Blocks", nullptr));
        b8x8CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "8x8, 8x16 and 16x8 B-frame Intra-predicted Blocks", nullptr));
        p4x4CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "4x4, 4x8 and 8x4 P-frame Intra-predicted Blocks", nullptr));
        i8x8CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "8x8 Intra-predicted Blocks", nullptr));
        i4x4CheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "4x4 Intra-predicted Blocks", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabPartition), QCoreApplication::translate("x264ConfigDialog", "Partition", nullptr));
        groupBoxFrameEnc->setTitle(QCoreApplication::translate("x264ConfigDialog", "Frame Encoding", nullptr));
        cabacCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "CABAC", nullptr));
        loopFilterCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Loop Filter:", nullptr));
        alphaC0Label->setText(QCoreApplication::translate("x264ConfigDialog", "Strength:", nullptr));
        betaLabel->setText(QCoreApplication::translate("x264ConfigDialog", "Threshold:", nullptr));
        openGopCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Open GOP:", nullptr));
        openGopComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Normal Mode", nullptr));
        openGopComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Blu-ray Mode", nullptr));

        interlacedCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Interlaced:", nullptr));
        interlacedComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Bottom Field First", nullptr));
        interlacedComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Top Field First", nullptr));

        labelRefFrames->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Reference Frames:", nullptr));
        groupBoxBframes->setTitle(QCoreApplication::translate("x264ConfigDialog", "B-frames", nullptr));
        label_33->setText(QCoreApplication::translate("x264ConfigDialog", "B-frames as References:", nullptr));
        bFrameRefComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Disabled", nullptr));
        bFrameRefComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Strictly Hierarchical Pyramid", nullptr));
        bFrameRefComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Non-strict (Not Blu-ray Compatible)", nullptr));

        adaptiveBFrameComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Disabled", nullptr));
        adaptiveBFrameComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Fast", nullptr));
        adaptiveBFrameComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Optimal", nullptr));

        label_29->setText(QCoreApplication::translate("x264ConfigDialog", "B-frame Bias:", nullptr));
        label_31->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Consecutive B-frames:", nullptr));
        label_4->setText(QCoreApplication::translate("x264ConfigDialog", "Adaptive B-frame Decision:", nullptr));
        groupBoxKeyFrames->setTitle(QCoreApplication::translate("x264ConfigDialog", "I-frames", nullptr));
        label_34->setText(QCoreApplication::translate("x264ConfigDialog", "GOP Size:", nullptr));
        label_28->setText(QCoreApplication::translate("x264ConfigDialog", "Minimum:", nullptr));
        label_26->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum:", nullptr));
        label_27->setText(QCoreApplication::translate("x264ConfigDialog", "I-frame Threshold:", nullptr));
        intraRefreshCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Periodic Intra Refresh", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabFrame), QCoreApplication::translate("x264ConfigDialog", "Frame", nullptr));
        groupBoxAnalysis->setTitle(QCoreApplication::translate("x264ConfigDialog", "Analysis", nullptr));
        mixedRefsCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Mixed References", nullptr));
        chromaMotionEstCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Chroma Motion Estimation", nullptr));
        trellisCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Trellis Quantization:", nullptr));
        trellisComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Final Macroblock Only", nullptr));
        trellisComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Always On", nullptr));

        fastPSkipCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Fast Skip Detection on P-frames", nullptr));
        dctDecimateCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "DCT Decimation on P-frames", nullptr));
        lblPsychoRDO->setText(QCoreApplication::translate("x264ConfigDialog", "Psychovisual Rate Distortion Optimisation:", nullptr));
        lblPsyTrellis->setText(QCoreApplication::translate("x264ConfigDialog", "Psychovisual Trellis:", nullptr));
        label_42->setText(QCoreApplication::translate("x264ConfigDialog", "Noise Reduction:", nullptr));
        groupBoxLumaQuant->setTitle(QCoreApplication::translate("x264ConfigDialog", "Luma Quantisation Deadzone", nullptr));
        label_44->setText(QCoreApplication::translate("x264ConfigDialog", "Intra Luma Quantisation Deadzone:", nullptr));
        label_43->setText(QCoreApplication::translate("x264ConfigDialog", "Inter Luma Quantisation Deadzone:", nullptr));
        groupBoxQuantMatrix->setTitle(QCoreApplication::translate("x264ConfigDialog", "Quantisation Matrix", nullptr));
        matrixFlatRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Flat Matrix", nullptr));
        matrixJvtRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "JVT Matrix", nullptr));
        matrixCustomRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Custom Matrix", nullptr));
        matrixCustomEditButton->setText(QCoreApplication::translate("x264ConfigDialog", "Edit", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAnalysis), QCoreApplication::translate("x264ConfigDialog", "Analysis", nullptr));
        groupBoxQuant->setTitle(QCoreApplication::translate("x264ConfigDialog", "Quantiser Control", nullptr));
        label_16->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Quantiser:", nullptr));
        label_6->setText(QCoreApplication::translate("x264ConfigDialog", "I and P-frame Quantiser Ratio:", nullptr));
        label_2->setText(QCoreApplication::translate("x264ConfigDialog", "%", nullptr));
        label_17->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Quantiser Step:", nullptr));
        label_7->setText(QCoreApplication::translate("x264ConfigDialog", "P and B-frame Quantiser Ratio:", nullptr));
        label_5->setText(QCoreApplication::translate("x264ConfigDialog", "Average Bitrate Tolerance:", nullptr));
        label_20->setText(QCoreApplication::translate("x264ConfigDialog", "Chroma to Luma Quantiser Offset:", nullptr));
        label_15->setText(QCoreApplication::translate("x264ConfigDialog", "Minimum Quantiser:", nullptr));
        groupBoxQuantCurveCompress->setTitle(QCoreApplication::translate("x264ConfigDialog", "Quantiser Curve Compression", nullptr));
        label_8->setText(QCoreApplication::translate("x264ConfigDialog", "Quantiser Curve Compression:", nullptr));
        label_18->setText(QCoreApplication::translate("x264ConfigDialog", "%", nullptr));
        label_21->setText(QCoreApplication::translate("x264ConfigDialog", "Reduce Fluctuation Before Curve Compression:", nullptr));
        label_22->setText(QCoreApplication::translate("x264ConfigDialog", "Reduce Fluctuation After Curve Compression:", nullptr));
        aqGroupBox->setTitle(QCoreApplication::translate("x264ConfigDialog", "Adaptive Quantisation", nullptr));
        aqVarianceCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Variance AQ:", nullptr));
        aqAlgoComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Normal", nullptr));
        aqAlgoComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Auto Variance", nullptr));
        aqAlgoComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Auto Variance Biased", nullptr));

        aqStrengthLabel->setText(QCoreApplication::translate("x264ConfigDialog", "Strength:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabQuantiser), QCoreApplication::translate("x264ConfigDialog", "Quantiser", nullptr));
        groupBox->setTitle(QCoreApplication::translate("x264ConfigDialog", "Video Buffer Verifier", nullptr));
        label_9->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum VBV Bitrate:", nullptr));
        label_14->setText(QCoreApplication::translate("x264ConfigDialog", "Initial VBV Buffer Occupancy:", nullptr));
        label_12->setText(QCoreApplication::translate("x264ConfigDialog", "kbit", nullptr));
        label_13->setText(QCoreApplication::translate("x264ConfigDialog", "%", nullptr));
        label_10->setText(QCoreApplication::translate("x264ConfigDialog", "kbit/s", nullptr));
        label_11->setText(QCoreApplication::translate("x264ConfigDialog", "VBV Buffer Size:", nullptr));
        slicingGroupBox->setTitle(QCoreApplication::translate("x264ConfigDialog", "Slicing", nullptr));
        label_25->setText(QCoreApplication::translate("x264ConfigDialog", "Slices per Frame:", nullptr));
        label_23->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Size per Slice:", nullptr));
        label_32->setText(QCoreApplication::translate("x264ConfigDialog", "bytes", nullptr));
        label_24->setText(QCoreApplication::translate("x264ConfigDialog", "Maximum Macroblocks per Slice:", nullptr));
        groupBoxZones->setTitle(QCoreApplication::translate("x264ConfigDialog", "Zones", nullptr));
        zoneAddButton->setText(QCoreApplication::translate("x264ConfigDialog", "Add", nullptr));
        zoneEditButton->setText(QCoreApplication::translate("x264ConfigDialog", "Edit", nullptr));
        zoneDeleteButton->setText(QCoreApplication::translate("x264ConfigDialog", "Delete", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced1), QCoreApplication::translate("x264ConfigDialog", "Advanced 1", nullptr));
        groupBoxThreads->setTitle(QCoreApplication::translate("x264ConfigDialog", "Multithreading", nullptr));
        threadDisableRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Disable", nullptr));
        threadAutoDetectRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Auto-detect", nullptr));
        threadCustomRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Custom:", "multithreading"));
        repeatabilityCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Enforce Repeatability", nullptr));
        sliceThreadingCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Slice-based Threading", nullptr));
        threadedLookaheadCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Custom Threaded Lookahead Buffer:", nullptr));
        lblThreadedFrames->setText(QCoreApplication::translate("x264ConfigDialog", "frames", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced2), QCoreApplication::translate("x264ConfigDialog", "Advanced 2", nullptr));
        groupBoxOutput->setTitle(QCoreApplication::translate("x264ConfigDialog", "Output", nullptr));
        accessUnitCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Generate Access Unit Delimiters", nullptr));
        blueRayCompat->setText(QCoreApplication::translate("x264ConfigDialog", "BluRay compatibility", nullptr));
        fakeInterlaced->setText(QCoreApplication::translate("x264ConfigDialog", "Generate fake interlaced", nullptr));
        groupBoxAspectRatio->setTitle(QCoreApplication::translate("x264ConfigDialog", "Pixel Aspect Ratio", nullptr));
        sarCustomRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Custom:", "PAR"));
        sarAsInputRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "As Input", nullptr));
        sarAsInputLabel->setText(QString());
        sarCustomLabel->setText(QCoreApplication::translate("x264ConfigDialog", ":", nullptr));
        sarPredefinedRadioButton->setText(QCoreApplication::translate("x264ConfigDialog", "Predefined Aspect Ratio:", nullptr));
        sarPredefinedComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "16:15 (PAL 4:3)", nullptr));
        sarPredefinedComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "64:45 (PAL 16:9)", nullptr));
        sarPredefinedComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "8:9 (NTSC 4:3)", nullptr));
        sarPredefinedComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "32:27 (NTSC 16:9)", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tabOutput1), QCoreApplication::translate("x264ConfigDialog", "Output 1", nullptr));
        groupBoxVui->setTitle(QCoreApplication::translate("x264ConfigDialog", "Video Usability Information", nullptr));
        label_52->setText(QCoreApplication::translate("x264ConfigDialog", "These settings are only suggestions for the playback equipment.  Use at your own risk.", nullptr));
        label_51->setText(QCoreApplication::translate("x264ConfigDialog", "Overscan:", nullptr));
        overscanComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Undefined", nullptr));
        overscanComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Show", nullptr));
        overscanComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "Crop", nullptr));

        label_50->setText(QCoreApplication::translate("x264ConfigDialog", "Video Format:", nullptr));
        videoFormatComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Undefined", nullptr));
        videoFormatComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "Component", nullptr));
        videoFormatComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "PAL", nullptr));
        videoFormatComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "NTSC", nullptr));
        videoFormatComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "SECAM", nullptr));
        videoFormatComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "MAC", nullptr));

        label_19->setText(QCoreApplication::translate("x264ConfigDialog", "Colour Primaries:", nullptr));
        colourPrimariesComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Undefined", nullptr));
        colourPrimariesComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "BT709", nullptr));
        colourPrimariesComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "BT470M", nullptr));
        colourPrimariesComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "BT470BG", nullptr));
        colourPrimariesComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "SMPTE170M", nullptr));
        colourPrimariesComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "SMPTE240M", nullptr));
        colourPrimariesComboBox->setItemText(6, QCoreApplication::translate("x264ConfigDialog", "Film", nullptr));

        label_48->setText(QCoreApplication::translate("x264ConfigDialog", "Transfer Characteristics:", nullptr));
        transferCharacteristicsComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Undefined", nullptr));
        transferCharacteristicsComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "BT709", nullptr));
        transferCharacteristicsComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "BT470M", nullptr));
        transferCharacteristicsComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "BT470BG", nullptr));
        transferCharacteristicsComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "Linear", nullptr));
        transferCharacteristicsComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "LOG100", nullptr));
        transferCharacteristicsComboBox->setItemText(6, QCoreApplication::translate("x264ConfigDialog", "LOG316", nullptr));
        transferCharacteristicsComboBox->setItemText(7, QCoreApplication::translate("x264ConfigDialog", "SMPTEL170M", nullptr));
        transferCharacteristicsComboBox->setItemText(8, QCoreApplication::translate("x264ConfigDialog", "SMPTE240M", nullptr));

        label_47->setText(QCoreApplication::translate("x264ConfigDialog", "Colour Matrix:", nullptr));
        colourMatrixComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "Undefined", nullptr));
        colourMatrixComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "BT709", nullptr));
        colourMatrixComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "FCC", nullptr));
        colourMatrixComboBox->setItemText(3, QCoreApplication::translate("x264ConfigDialog", "BT470BG", nullptr));
        colourMatrixComboBox->setItemText(4, QCoreApplication::translate("x264ConfigDialog", "SMPTE170M", nullptr));
        colourMatrixComboBox->setItemText(5, QCoreApplication::translate("x264ConfigDialog", "SMPTE240M", nullptr));
        colourMatrixComboBox->setItemText(6, QCoreApplication::translate("x264ConfigDialog", "GBR", nullptr));
        colourMatrixComboBox->setItemText(7, QCoreApplication::translate("x264ConfigDialog", "YCgCo", nullptr));

        hrdLabel->setText(QCoreApplication::translate("x264ConfigDialog", "HRD Parameters:", nullptr));
        hrdComboBox->setItemText(0, QCoreApplication::translate("x264ConfigDialog", "None", nullptr));
        hrdComboBox->setItemText(1, QCoreApplication::translate("x264ConfigDialog", "VBR", nullptr));
        hrdComboBox->setItemText(2, QCoreApplication::translate("x264ConfigDialog", "CBR", nullptr));

        label_49->setText(QCoreApplication::translate("x264ConfigDialog", "Chroma Sample Location:", nullptr));
        fullRangeSamplesCheckBox->setText(QCoreApplication::translate("x264ConfigDialog", "Full Range Samples", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabOutput2), QCoreApplication::translate("x264ConfigDialog", "Output 2", nullptr));
    } // retranslateUi

};

namespace Ui {
    class x264ConfigDialog: public Ui_x264ConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_X264CONFIGDIALOG_H
